<?php

// get values
if( isset( $a['option_arr_id'] ) ) { // if id of options array is given
	$arr = get_option( $a['option_arr_id'] ); // get the options array (returns false if not exists)
	if( ! empty ($arr) && isset( $arr[$a['field_id']] )) { // if options array and field value exist
		$value = $arr[$a['field_id']]; // get field value
	} else { // if array doesn't exist
		$value = isset( $a['default'] ) ? $a['default'] : false; // set default or nothing
	};

	$a['field_id'] = $a['option_arr_id'] . '['.$a['field_id'].']'; // generate field id
} else { // if id of options array is not given
	$value = get_option( $a['field_id'] ); // get the current field value (returns false if not exists)
	if( ! $value ) { // If no value exists
		$value = isset( $a['default'] ) ? $a['default'] : false; // set default or nothing
	}
}

// get placeholder
$placeholder = isset( $a['placeholder'] ) ? $a['placeholder'] : '';

// Add text before field
if( isset( $a['before field'] ) ){
	printf( '<span class="before-field">%s</span>', $a['before field'] ); // Show it
}

// Check which type of field we want
switch ( $a['type'] ){
	case 'text':
	case 'number':
	case 'password': // If it is a text field
		$el_class = ! empty ( $a['el_class'] ) ? $a['el_class'] : '';
		$el_data_target = ! empty ( $a['el_data_target'] ) ? $a['el_data_target'] : '';
		$disabled = ! empty ( $a['disabled'] ) ? ' disabled="' . esc_attr( $a['disabled'] ) . '"' : '';
		printf( '<input type="'.$a['type'].'" name="%1$s" id="%1$s" placeholder="%2$s" value="%3$s" class="%4$s" data-target="%5$s" %6$s/>', $a['field_id'], $placeholder, $value, $el_class, $el_data_target, $disabled );
	break;
	case 'checkbox':
		$el_class = ! empty ( $a['el_class'] ) ? $a['el_class'] : '';
		$el_data_target = ! empty ( $a['el_data_target'] ) ? $a['el_data_target'] : '';
		printf( '<input type="checkbox" name="%1$s" id="%1$s" value="1" %2$s class="%3$s" data-target="%4$s"/>', $a['field_id'], checked(1, $value, false), $el_class, $el_data_target );
	break;
	case 'toggle':
		$el_class = ! empty ( $a['el_class'] ) ? $a['el_class'] : '';
		$el_data_target = ! empty ( $a['el_data_target'] ) ? $a['el_data_target'] : '';
		$el_data_name = ! empty ( $a['el_data_name'] ) ? $a['el_data_name'] : '';
		printf( '<label class="fupi_switch"><input type="checkbox" name="%1$s" id="%1$s" value="1" %2$s class="%3$s" data-target="%4$s" data-name="%5$s"/><span class="fupi_slider"></span></label>', $a['field_id'], checked(1, $value, false), $el_class, $el_data_target, $el_data_name );
	break;
	case 'multi checkbox':
		if( ! empty ( $a['options'] ) && is_array( $a['options'] ) ){
			foreach( $a['options'] as $key => $label ) {

				$checked = false;

				if ( is_array( $value ) ) {
					if ( in_array( $key, $value) ){
						$checked = true;
					}
				} else if ( $value == $key ) {
					$checked = true;
				}

				$option_class = '';
				if ( ! empty ( $a['options_classes'] ) && ! empty ( $a['options_classes'][$key] ) ) {
					$option_class = $a['options_classes'][$key];
				}

				$option_data_target= '';
				if ( ! empty ( $a['options_data_targets'] ) && ! empty ( $a['options_data_targets'][$key] ) ) {
					$option_data_target = $a['options_data_targets'][$key];
				}

				printf(
					'<label><input type="checkbox" name="%1$s[]" value="%2$s" id="%1$s_%2$s" %4$s class="%5$s" data-target="%6$s">%3$s</label><div class="fupi_spacer"></div>',
					$a['field_id'],
					$key,
					$label,
					checked( $checked, true, false ),
					$option_class,
					$option_data_target
				);
			}
			break;
		} else { break; }
	break;
	case 'roles multi checkbox':

		global $wp_roles;
		$roles = $wp_roles->roles;

		foreach( $roles as $key => $data_arr ) {

			$checked = false;

			if ( is_array( $value ) ) {
				if ( in_array( $key, $value) ){
					$checked = true;
				}
			} else if ( $value == $key ) {
				$checked = true;
			}

			printf(
				'<label><input type="checkbox" name="%1$s[]" value="%2$s" id="%1$s_%2$s" %4$s">%3$s</label><div class="fupi_spacer"></div>',
				$a['field_id'],
				$key,
				$data_arr['name'],
				checked( $checked, true, false )
			);
		};

	break;

	case 'taxonomies multi checkbox':

		$taxonomies = get_taxonomies();
		$fupi_main = get_option('fupi_main');
		$skip_fupi_labels= isset( $fupi_main['label_pages'] ) && isset( $fupi_main['label_as_page_types'] );

		// change old text field with a string with coma delimited slugs to array
		if ( is_string( $value ) ){
			$value = explode(',', $value);
			$value = array_map( 'trim', $value);
		}

		foreach( $taxonomies as $tax_slug ){

			if ( $tax_slug == 'fupi_page_labels' && $skip_fupi_labels ) continue;

			$checked = false;

			if ( is_array( $value ) ) {
				if ( in_array( $tax_slug, $value) ){
					$checked = true;
				}
			} else if ( $value == $tax_slug ) {
				$checked = true;
			}

			printf(
				'<label><input type="checkbox" name="%1$s[]" value="%2$s" id="%1$s_%2$s" %4$s">%3$s</label><div class="fupi_spacer"></div>',
				$a['field_id'],
				$tax_slug,
				$tax_slug,
				checked( $checked, true, false )
			);
		};

	break;

	case 'taxonomies select':
		$taxonomies = get_taxonomies();

		$options_markup = '<option value=\'\'>' . esc_html__('None', 'fupi') . '</option>';
		$el_class = ! empty ( $a['el_class'] ) ? $a['el_class'] : '';
		$el_data_target = ! empty ( $a['el_data_target'] ) ? $a['el_data_target'] : '';

		foreach( $taxonomies as $tax_slug ){
			$options_markup .= sprintf( '<option value="%s" %s>%s</option>', $tax_slug, selected( $value, $tax_slug, false ), $tax_slug );
		}

		printf( '<select name="%1$s" id="%1$s" class="%2$s" data-target="%3$s">%4$s</select>', $a['field_id'], $el_class, $el_data_target, $options_markup );

	break;
	case 'textarea': // If it is a textarea
		$el_class = ! empty ( $a['el_class'] ) ? $a['el_class'] : '';
		$el_data_target = ! empty ( $a['el_data_target'] ) ? $a['el_data_target'] : '';
		printf( '<textarea name="%1$s" id="%1$s" placeholder="%2$s" rows="5" cols="50" class="%4$s" data-target="%5$s">%3$s</textarea>', $a['field_id'], $placeholder, $value, $el_class, $el_data_target );
	break;

	case 'repeater': // Textarea transformed into multi field
		$el_class = ! empty ( $a['el_class'] ) ? $a['el_class'] : '';
		$el_data_field1_txt = ! empty ( $a['el_data_field1_txt'] ) ? $a['el_data_field1_txt'] : '';
		$el_data_field1_type = ! empty ( $a['el_data_field1_type'] ) ? $a['el_data_field1_type'] : 'selector';
		$el_data_field1_req = ! empty ( $a['el_data_field1_req'] ) ? $a['el_data_field1_req'] : '';
		$el_data_field1_err = ! empty ( $a['el_data_field1_err'] ) ? $a['el_data_field1_err'] : '';
		$el_data_field2_txt = ! empty ( $a['el_data_field2_txt'] ) ? $a['el_data_field2_txt'] : '';
		$el_data_field2_req = ! empty ( $a['el_data_field2_req'] ) ? $a['el_data_field2_req'] : '';
		$el_data_field2_err = ! empty ( $a['el_data_field2_err'] ) ? $a['el_data_field2_err'] : '';
		$el_data_target = ! empty ( $a['el_data_target'] ) ? $a['el_data_target'] : '';
		printf( '<textarea name="%1$s" id="%1$s" rows="5" cols="50" class="fupi_repeater %3$s" data-target="%4$s" data-field1_txt="%5$s" data-field1_req="%6$s" data-field1_err="%7$s" data-field2_txt="%8$s" data-field2_req="%9$s" data-field2_err="%10$s" data-field1_type="%11$s">%2$s</textarea>', $a['field_id'], $value, $el_class, $el_data_target, $el_data_field1_txt, $el_data_field1_req, $el_data_field1_err, $el_data_field2_txt, $el_data_field2_req, $el_data_field2_err, $el_data_field1_type );
	break;

	case 'select': // If it is a select dropdown
		if( ! empty ( $a['options'] ) && is_array( $a['options'] ) ){
			$options_markup = '';
			$el_class = ! empty ( $a['el_class'] ) ? $a['el_class'] : '';
			$el_data_target = ! empty ( $a['el_data_target'] ) ? $a['el_data_target'] : '';

			foreach( $a['options'] as $key => $label ){
				$options_markup .= sprintf( '<option value="%s" %s>%s</option>', $key, selected( $value, $key, false ), $label );
			}

			printf( '<select name="%1$s" id="%1$s" class="%2$s" data-target="%3$s">%4$s</select>', $a['field_id'], $el_class, $el_data_target, $options_markup );
		}
	break;
	case 'radio':
		if( ! empty ( $a['options'] ) && is_array( $a['options'] ) ){
			$options_markup = '';
			foreach( $a['options'] as $key => $label ) {

				$option_class = '';
				if ( ! empty ( $a['options_classes'] ) && ! empty ( $a['options_classes'][$key] ) ) {
					$option_class = $a['options_classes'][$key];
				}

				$option_data_target= '';
				if ( ! empty ( $a['options_data_targets'] ) && ! empty ( $a['options_data_targets'][$key] ) ) {
					$option_data_target = $a['options_data_targets'][$key];
				}

				$checked = $value == $key ? true : false;

				printf(
					'<label><input type="radio" name="%1$s" value="%2$s" id="%1$s_%2$s" %4$s class="%5$s" data-target="%6$s">%3$s</label><div class="fupi_spacer"></div>',
					$a['field_id'],
					$key,
					$label,
					checked( $checked, true, false ),
					$option_class,
					$option_data_target
				);
			}
			break;
		} else { break; }
	break;
	case 'hidden':
		printf( '<input type="hidden" name="%1$s" id="%1$s" value="%2$s"/>', $a['field_id'], $value );
		break;
	case 'empty':
	break;
}

// Add tooltip after field
if( isset( $a['tooltip'] ) ){
	printf( '<div class="fupi_tooltip">?<span class="fupi_tooltiptext">%s</span></div>', $a['tooltip'] );
}

// Add text after field
if( isset( $a['after field'] ) ){
	printf( '<span class="fupi_after_field"> %s</span>', $a['after field'] );
}

// Add text below field
if( isset( $a['under field'] ) ){
	printf( '<p class="fupi_under_field">%s</p>', $a['under field'] );
}

?>
