(() => {

	// DISABLE SECTIONS NOT AVAILABLE FOR FREE USERS

	let premium_opts = FP.findAll('.fupi_disable_for_free input, .fupi_disable_for_free textarea, .fupi_disable_for_free select');
	premium_opts.forEach( opt => { opt.disabled = true; })
})();

// CREATE LINKS TO SECTIONS (IN SIDEBAR)

(() => {

	let fupi_settings_form = FP.findID('fupi_settings_form'),
		fupi_admin_page = FP.getUrlParamByName('page');

	if ( fupi_admin_page && fupi_admin_page != 'full_picture_tools' ) {

		let headlines = FP.findAll( '#fupi_settings_form h2' );

		if ( headlines.length > 1 ) {

			let form = FP.findFirst('#fupi_settings_form'),
				section_nav = FP.findID('fupi_page_nav'),
				active_nav_tab = FP.findFirst('.nav-tab-active');

			if ( form ) {

				let section_links = '',
					active_tab = form.dataset.activetab,
					is_pro_code = ! FP.findID('fupi_hide_pro');

				headlines.forEach( ( headline, i ) => {

					let h_txt = headline.innerText,
						extra_class = '';

					if ( i == 0 ) {
						section_links += '<p class="fupi_page_nav_section">' + section_nav.dataset.basictxt + '</p>';
						active_class = ' active';
					} else {
						active_class = '';
					}

					// add "Deprecated" menu separator
					if ( h_txt.indexOf('**') != -1 ){

						section_links += '<p class="fupi_page_nav_section">' + section_nav.dataset.deprtxt + '</p>';
						h_txt = h_txt.replace('**','');
						headline.innerText = h_txt;

					// add "Optional" menu separator
					} else if ( h_txt.indexOf('*') != -1 ){

						section_links += '<p class="fupi_page_nav_section">' + section_nav.dataset.opttxt + '</p>';
						h_txt = h_txt.replace('*','');
						headline.innerText = h_txt;
					}

					if ( h_txt.indexOf('(PRO)') != -1 ){
						if ( is_pro_code ) {
							h_txt = h_txt.replace('(PRO)','');
							headline.innerText = h_txt;
						} else {
							h_txt = h_txt.replace('(PRO)','');
							headline.innerText = h_txt;
							headline.classList.add('fupi_pro_label');
							extra_class = ' fupi_pro_label';
						}
					}

					section_links += '<button type="button" data-target="hook_' + active_tab + '_' + i + '" class="fupi_pseudo_link' + active_class + extra_class + '">' + h_txt + '</button>';
					headline.setAttribute( 'id', 'hook_' + active_tab + '_' + i );
					headline.classList.add( 'fupi_hook', 'fupi_el');
				});

				section_nav.insertAdjacentHTML( 'afterbegin', section_links );
			}
		} else {
			let fupi_content = FP.findID('fupi_content');
			if ( fupi_content ) {
				fupi_content.classList.remove('has_side_col');
				fupi_content.classList.add('no_side_col');
			}
		}

		// TOGGLE SECTIONS

		// headlines = FP.findAll('#fupi_settings_form h2');

		let fupi_page_nav_links = FP.findAll('#fupi_page_nav .fupi_pseudo_link');

		// make 1st section visible & unhide form
		if ( headlines.length > 1 ) show_section( headlines[0].id ); // show first section
		if ( fupi_settings_form ) fupi_settings_form.classList.remove('fupi_hidden');

		// add events to links that add a hook to url & reload the page
		if ( fupi_page_nav_links.length > 1 ) {

			fupi_page_nav_links.forEach( link => {
				link.addEventListener( 'click', () => {
					if ( ! link.classList.contains('active') ) {
						FP.findFirst('#fupi_page_nav .fupi_pseudo_link.active').classList.remove('active');
						let hook = link.dataset.target;
						show_section( hook );
					}
				} )
			} )
		}

	} else {
		fupi_settings_form.classList.remove('fupi_hidden');
	}

	// SHOW SECTION
	function show_section( hook ) {

		let section_elements 	= FP.findAll( '.fupi_el, .form-table' ),
		pseudo_link 			= FP.findFirst( '.fupi_pseudo_link[data-target="' + hook + '"]' );

		// hide all sections
		section_elements.forEach( element => element.classList.add('fupi_hidden'));
		// show chosen section
		FP.findAll('#' + hook + ', #' + hook + '+*, #' + hook + '+*+table').forEach( element => element.classList.remove('fupi_hidden'));

		// add class to current pseudo link
		pseudo_link.classList.add('active');
	}

})();

// SHOWING / HIDING HELP SECTIONS

(()=>{

	// FNs

	function getCookie() {
		let cookie = FP.readCookie( 'fp_admin_help' );
		return cookie ? JSON.parse( cookie ) : [];
	}

	function hideHelp( btn, update_cookie ) {

		let helpID = btn.dataset.toggle_id;

		FP.findID( helpID ).parentElement.classList.add('fupi_help_hidden');

		if ( update_cookie ) {
			let cookie = getCookie();
			cookie.push( helpID );
			FP.setCookie( 'fp_admin_help', JSON.stringify( cookie ), 3650 );
		}
	}

	function showHelp( btn, update_cookie ) {

		let helpID = btn.dataset.toggle_id;

		FP.findID( helpID ).parentElement.classList.remove('fupi_help_hidden');

		if ( update_cookie ) {

			let cookie = getCookie(),
				index_helpID = cookie.indexOf( helpID );

			if ( index_helpID != -1 ) {
				cookie.splice( index_helpID, 1 );
				FP.setCookie( 'fp_admin_help', JSON.stringify( cookie ), 3650 );
			}
		}
	}

	// VARS

	let help_toggle_btns = FP.findAll('.fupi_help_toggle_btn'),
		help_close_btn = FP.findAll('.fupi_close_btn'),
		cookie = getCookie();

	// TOGGLE HELP
	// when "x" and "configuration help" buttons are pressed

	if ( help_toggle_btns.length > 0 ) {

		help_toggle_btns.forEach( btn => {

			// hide help if it was previously hidden
			if ( cookie.length > 0 && cookie.indexOf( btn.dataset.toggle_id ) != -1 ) { hideHelp( btn, false ) };

			// toggle help on click
			btn.addEventListener('click', e => {
				e.target.parentElement.classList.contains('fupi_help_hidden') ? showHelp( e.target, true ) : hideHelp( e.target, true );
			} );

		})

		help_close_btn.forEach( btn => {
			btn.addEventListener( 'click', e => { hideHelp( e.target, true ) } )
		} )
	}

})();

// CONDITIONS

(() => {

	let fields = FP.findAll( '.fupi_condition' );

	if ( fields.length > 0 ) {

		fields.forEach( field => {

			// after pageload
			sync_settings( field );

			// after click
			field.onclick = (e) => { sync_settings( field ); };

			// on key up
			field.onkeyup = (e) => { sync_settings( field ); }
		})
	};

	function sync_settings( field ) {

		let field_type = field.getAttribute('type') || field.tagName.toLowerCase(),
			table_rows = FP.findAll('.' + field.dataset.target),
			val = false;

		switch (field_type) {

			case 'checkbox':
				toggle_rows(table_rows, field.checked);
			break;

			case 'number':
				val = field.value != 0 ? true : false;
				toggle_rows(table_rows, val);
			break;

			case 'text':
			case 'textarea':
				val = !!field.value;
				toggle_rows(table_rows, val);
			break;

			case 'select' :
				val = field.value;
				toggle_rows(table_rows, val, 'select');
			break;

		}
	}

	function toggle_rows( table_rows, val, field_type ) {

		table_rows.forEach( row => {

			if ( ! row.classList.contains('fupi_disable_for_free') ) {

				let inputs = FP.findAll( 'input, textarea, select', row );

				if ( field_type != 'select' ) {

					let enabled = val;
					enabled ? row.classList.remove( 'fupi_disabled' ) : row.classList.add( 'fupi_disabled' ); // toggle class on table row

					// toggle state of inputs
					if ( inputs.length > 0) {
						inputs.forEach( input => {
							input.disabled = ! enabled;
						})
					}

				} else {

					if ( row.classList.contains('fupi_cond_val_' + val ) ) {
						row.classList.remove( 'fupi_disabled' );
						inputs.forEach( input => input.disabled = false )
					} else {
						row.classList.add( 'fupi_disabled' );
						inputs.forEach( input => input.disabled = true )
					}
				}
			}
		})
	}

})();

// FILTER THE LIST OF TOOLS

(() => {

	function add_event_to_filter() {

		// FITLER TOOLS BY TYPE

		let select_filter = FP.findFirst('#fupi_tools_filter select');

		select_filter.addEventListener('change', e => {

			let choice = e.target.value,
				tools = FP.findAll('.fupi_tag');

			if ( !!choice ){

				let chosen_tools = FP.findAll('.'+ choice);

				tools.forEach( tool => {
					tool.style.display = "none";
				});

				chosen_tools.forEach( chosen_tool => {
					chosen_tool.style.display = "table-row";
				})
			} else {
				tools.forEach( tool => {
					tool.style.display = "table-row";
				})
			}
		});

		// FILTER TOOLS BY COOKIE USAGE

		let nocookie_switch = FP.findID('fupi_show_nocookie_tools_switch');

		// toggle tools after click

		nocookie_switch.addEventListener( 'click', e => {

			if ( e.target.checked ) {
				document.body.classList.add('fupi_cookie_tools_hidden');
			} else {
				document.body.classList.remove('fupi_cookie_tools_hidden');
			}
		})

		// FILTER TOOLS BY DASHBOARD STATS

		let admindash_switch = FP.findID('fupi_show_admindash_tools_switch');

		// toggle tools after click

		admindash_switch.addEventListener( 'click', e => {

			if ( e.target.checked ) {
				document.body.classList.add('fupi_admindash_tools_hidden');
			} else {
				document.body.classList.remove('fupi_admindash_tools_hidden');
			}
		})
	}

	if ( FP.findID('fupi_tools_filter') ) {
		console.log('filtering enabled');
		add_event_to_filter();
	}
})();

// REPEATER

(() => {

	let textareas = FP.findAll('.fupi_repeater'),
		template = '<div class="fupi_repeater_line_wrap fupi_repeater_template">'+
		 	'<div class="fupi_repeater_fields_wrap fupi_ok">' +
				'<div class="fupi_repeater_p1_wrap">' +
					'<input class="fupi_repeater_field fupi_repeater_p1 fupi_required" type="text">' +
					'<span class="fupi_error_msg fupi_error_msg_p1" style="display: none;"></span>' +
					'<span class="fupi_required_msg fupi_required_msg_p1" style="display: none;"></span>' +
				'</div>' +
				'<div class="fupi_repeater_p2_wrap">' +
					'<input class="fupi_repeater_field fupi_repeater_p2" type="text">' +
					'<span class="fupi_error_msg fupi_error_msg_p2" style="display: none;"></span>' +
					'<span class="fupi_required_msg fupi_required_msg_p2" style="display: none;"></span>' +
				'</div>' +
			'</div>'+
			'<div class="fupi_repeater_btns_wrap">' +
				'<button type="button" class="fupi_repeater_btn fupi_repeater_btn_remove dashicons dashicons-minus"></button>' +
				'<button type="button" class="fupi_repeater_btn fupi_repeater_btn_add dashicons dashicons-plus-alt2"></button>' +
			'</div>' +
		'</div>';

	function add_repeater_fields( textarea, placement, line_content, is_disabled ) {

		// Add template to page
		placement.insertAdjacentHTML('afterend', template);

		let content = line_content ? line_content.split('@') : ['',''],
			addedTemplate = FP.findFirst('.fupi_repeater_template'),
			field1 = FP.findFirst('.fupi_repeater_p1', addedTemplate),
			field2 = FP.findFirst('.fupi_repeater_p2', addedTemplate),
			field2_req_text = textarea.dataset.field2_req;

		// Fill it with data

		// field 1
		field1.value = content[0];
		field1.disabled = is_disabled;
		field1.placeholder = textarea.dataset.field1_txt;
		field1.dataset.type = textarea.dataset.field1_type;
		FP.findFirst( '.fupi_error_msg_p1', addedTemplate ).textContent = textarea.dataset.field1_err;
		FP.findFirst( '.fupi_required_msg_p1', addedTemplate ).textContent = textarea.dataset.field1_req;

		// field 2
		field2.value = content[1] || '';
		field2.disabled = is_disabled;
		field2.placeholder = textarea.dataset.field2_txt;
		FP.findFirst( '.fupi_error_msg_p2', addedTemplate ).textContent = textarea.dataset.field2_err || '';
		if ( field2_req_text ) {
			field2.classList.add('fupi_required');
			FP.findFirst( '.fupi_required_msg_p2', addedTemplate ).textContent = field2_req_text;
		}

		// Remove template class
		addedTemplate.classList.remove('fupi_repeater_template');
	}

	function enable_line_buttons() {

		let form = FP.findID('fupi_settings_form');

		if ( form ) {
			form.addEventListener('click', e => {
				let target = e.target;
				if ( target.classList.contains('fupi_repeater_btn') ) {

					let btns_wrap = target.closest( '.fupi_repeater_line_wrap'),
						textarea = btns_wrap.previousElementSibling;

					if ( textarea && ! textarea.disabled ) {

						// remove line
						if ( target.classList.contains('fupi_repeater_btn_remove') ) {

							let fields_line = target.closest('.fupi_repeater_line_wrap'),
							repeater_section = target.closest('.fupi_repeater_section');

							FP.remove(fields_line);
							update_textarea(false, repeater_section);

						// add line
						} else {
							let fupi_repeater_section = target.closest('.fupi_repeater_section'),
							textarea = FP.findFirst('textarea', fupi_repeater_section),
							line_with_clicked_btn = target.closest('.fupi_repeater_line_wrap');

							add_repeater_fields(textarea, line_with_clicked_btn, false, false)
						}
					}
				}
			})
		}
	}

	function create_repeater_fields () {

		textareas.forEach( textarea => {

			let value = textarea.value,
				lines = value ? value.split(/\r?\n/) : [''], // split lines into array (if there are no lines create an empty array)
				lines_reversed = lines.reverse(),
				is_disabled = textarea.disabled;

			// create fields for each line
			lines_reversed.forEach( line => add_repeater_fields( textarea, textarea, line, is_disabled ) )

		} )
	}

	function is_selector_valid ( sel ) {
		try { document.querySelector( sel ) } catch (e) { return false; }
		return true;
	}

	function toggle_error_msg( field ) {

		let is_field_1 = field.classList.contains('fupi_repeater_p1'),
			error_msg = FP.findFirst( '.fupi_error_msg', field.parentElement );

		// for field 1
		if ( is_field_1 ) {

			// if field value is a CSS selector
			if ( field.dataset.type == 'selector' ) {

				if ( is_selector_valid( field.value ) ) {
					error_msg.style.display = 'none';
					field.classList.remove('fupi_error');
				} else {
					field.classList.add('fupi_error');
					error_msg.style.display = 'block';
				}
			}

		// if field 2
		} else {

			// if string contains characters from outside this list
			if ( /[^A-Za-z0-9 \-\_\[\]]/.test( field.value ) ) {
				field.classList.add('fupi_error');
				error_msg.style.display = 'block';
			} else {
				error_msg.style.display = 'none';
				field.classList.remove('fupi_error');
			}
		}
	}

	function toggle_required_msg( field ) {

		if ( field.classList.contains('fupi_required') ) {

			let req_msg = FP.findFirst( '.fupi_required_msg', field.parentElement );

			if ( field.value ) {
				field.classList.remove('fupi_empty');
				req_msg.style.display = 'none';
			} else {
				field.classList.add('fupi_empty');
				req_msg.style.display = 'block';
			}
		}
	}

	function mark_ok_lines( field ) {

		// check if all the required fields in this "line" are filled in correctly

		let fields_wrap = field.closest('.fupi_repeater_fields_wrap'),
		 	repeater_fields_with_errors = FP.findAll('.fupi_repeater_field.fupi_empty, .fupi_repeater_field.fupi_error', fields_wrap);

		repeater_fields_with_errors.length == 0 ? fields_wrap.classList.add('fupi_ok') : fields_wrap.classList.remove('fupi_ok');
	}

	function update_textarea( field, repeater_section = false) {

		// copy to textarea values of all correctly filled in fields

		let r_section = repeater_section || field.closest('.fupi_repeater_section'),
			field_wraps = FP.findAll('.fupi_ok', r_section), // get all fields from lines that have no erros
			textarea = FP.findFirst('textarea', r_section),
			new_val = '';

		if ( field_wraps.length > 0 ) {
			field_wraps.forEach( wrap => {

				let fields = FP.findAll('input', wrap).filter( input => !!input.value );

				if ( fields.length > 0 ) {
					if ( fields.length > 1 ) {
						new_val += fields[0].value.trim() + '@' + fields[1].value.trim()  + "\n";
					} else {
						new_val += fields[0].value.trim() + "\n";
					}
				}

			} )
		}

		textarea.value = new_val.trim();

		// trigger keyup event on textarea (for other functions to work properly)
		textarea.click();
	}

	// init
	if ( textareas ) {

		create_repeater_fields();
		enable_line_buttons();

		// when repeater fields lose focus...

		document.addEventListener('focusout', e => {

			let field = e.target;

			if ( field.classList && field.classList.contains('fupi_repeater_field') ){
				toggle_error_msg( field );
				toggle_required_msg( field );
				mark_ok_lines( field );
				update_textarea( field );
			}
		})
	}
})();

(()=>{

	// VIDEO POPUP

	let video_teasers = FP.findAll('a.fupi_vid');

	function create_popup(){

		if ( !FP.findID('fupi_popup') ){
			FP.findID('fupi_content').insertAdjacentHTML('afterend', '<div id="fupi_popup"><div id="fupi_popup_overlay"></div><div id="fupi_popup_inner"><button type="button" id="fupi_close_popup_btn">&times;</button><div id="fupi_popup_content"></div></div></div>');
		}
	}

	function add_vid_to_popup( vid_teaser ){

		let current_vid = FP.findFirst('#fupi_popup_content iframe'),
			vid_src = 'https://www.youtube-nocookie.com/embed/' + vid_teaser.dataset.srcid;

		if ( !current_vid || current_vid.src != vid_src ) {
			FP.findID('fupi_popup_content').innerHTML = '<div class="fupi_video"><iframe width="560" height="315" src="' + vid_src + '" title="YouTube video player" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture" allowfullscreen></iframe><div>'
		}
	}

	function show_popup(){
		FP.findID('fupi_popup').classList.remove('fupi_hidden');
	}

	function hide_popup(){
		FP.findID('fupi_popup').classList.add('fupi_hidden');
	}

	function add_once_close_listeners(){
		if ( ! FP.findID('fupi_popup').classList.contains('fupi_close_listeners_added') ) {
			FP.findID('fupi_popup').classList.add('fupi_close_listeners_added');
			FP.findID('fupi_close_popup_btn').addEventListener( 'click', e => { hide_popup() });
		}
	}

	function open_popup( vid_teaser ){
		create_popup( vid_teaser );
		add_vid_to_popup( vid_teaser );
		show_popup();
		add_once_close_listeners();
	}

	video_teasers.forEach( vid_teaser => {
		vid_teaser.addEventListener( 'click', e => {

			FP.updateViewportDimensions();

			if ( FP.v.viewport.width > 600 && FP.v.viewport.height > 450 )  {
				e.preventDefault();
				open_popup( vid_teaser );
			}
		});
	})

})();

(()=>{

	// HIDE PRO MODE

	let pro_switch = FP.findID('fupi_hide_pro_switch');

	if ( pro_switch ) {

		// toggle PRO features after load

		if ( FP.readCookie('fupi_hide_pro') ) {
			pro_switch.classList.add('fupi_block');
			pro_switch.click();
			document.body.classList.add('fupi_pro_hidden');
			pro_switch.classList.remove('fupi_block');
		};

		// toggle PRO features after click

		pro_switch.addEventListener( 'click', e => {

			if ( ! pro_switch.classList.contains('fupi_block') ) {

				let is_pro_hidden = e.target.checked;

				if ( is_pro_hidden ) {
					FP.setCookie( 'fupi_hide_pro', true, 3650 );
					document.body.classList.add('fupi_pro_hidden');
				} else {
					FP.deleteCookie( 'fupi_hide_pro' );
					document.body.classList.remove('fupi_pro_hidden');
				}
			}
		})
	}

})();

(()=>{

	// SHOW "FIRST STEPS" VIDEO AFTER PLUGIN ACTIVATION

	if ( FP.getUrlParamByName('intro') == 'true' ){
		let intro_link = FP.findID('fupi_intro_vid_link')
		if ( intro_link ) intro_link.click();
	}

	// MARK THE TOOL AS ENABLED
})();
