<?php

$page = 'fupi_gtm';

// Integration setup

$section_id = 'fupi_gtm_main';
add_settings_section( $section_id, esc_html__( 'Basic settings', 'fupi' ), array( $this, 'fupi_sections_descriptions'), $page );

$fields = array(
	array(
		'type'	 			=> 'text',
		'label' 			=> esc_html__( 'Container ID', 'fupi' ),
		'field_id' 			=> 'id',
		'class'				=> 'fupi_required fupi_easy',
		'option_arr_id'		=> $option_arr_id,
		'label_for' 		=> $option_arr_id . '[id]',
		'placeholder'		=> 'GTM-0000000',
		'under field'		=> sprintf( esc_html__( 'Read this article to know %1swhere to find your container ID%2s.', 'fupi' ), '<a href="https://www.optimizesmart.com/how-to-get-google-tag-manager-container-id/" target="_blank">','</a>' )
	),
	array(
		'type'	 			=> 'radio',
		'label' 			=> esc_html__( 'Rename data layer', 'fupi' ),
		'field_id' 			=> 'datalayer',
		'class'				=> 'fupi_easy',
		'option_arr_id'		=> $option_arr_id,
		'options' 			=> array(
			'default'			=> esc_html__( 'dataLayer (default)', 'fupi' ),
			'fupi'				=> esc_html__( 'fupi_dataLayer', 'fupi' ),
		),
		'default'			=> 'dataLayer',
		'under field'		=> esc_html__( 'Use it if you also use Google Analytics. Renaming prevents the data layer from being polluted with data from Google Analytics.', 'fupi'),
	),
	array(
		'type'	 			=> 'toggle',
		'label' 			=> esc_html__( 'Send to GTM what types of cookies the visitors agreed to', 'fupi' ),
		'field_id' 			=> 'pass_cookies',
		'class'				=> 'fupi_easy',
		'option_arr_id'		=> $option_arr_id,
	),
);

foreach( $fields as $field ){
	add_settings_field( $field['field_id'], $field['label'], array( $this, 'fupi_field_html' ), $page, $section_id, $field );
}

// CLICK TRACKING

$section_id = 'fupi_gtm_clicks';
add_settings_section( $section_id, esc_html__( 'Track clicks*', 'fupi' ), array( $this, 'fupi_sections_descriptions'), $page );

$fields = array(
	array(
		'type'	 			=> 'toggle',
		'label' 			=> esc_html__( 'Track clicks on outbound links', 'fupi' ),
		'field_id' 			=> 'track_outbound',
		'class'				=> 'fupi_standard',
		'option_arr_id'		=> $option_arr_id,
		'under field'		=> esc_html__( 'Tracks clicks on all links that lead to other domains. Attention! Affiliate links leading to other sites are also treated as outbound.', 'fupi'),
	),
	array(
		'type'	 			=> 'repeater',
		'label' 			=> esc_html__( 'Track clicks on affiliate links', 'fupi' ),
		'field_id' 			=> 'track_affiliate',
		'class'				=> 'fupi_repeater_section',
		'el_data_field1_txt' => esc_html__( 'url part, e.g. /go/', 'fupi' ),
		'el_data_field1_type' => 'url_part',
		'el_data_field1_req' => esc_html__( 'this field is required', 'fupi' ),
		'el_data_field1_err' => '',
		'el_data_field2_txt' => esc_html__( 'name (optional)', 'fupi' ),
		'el_data_field2_req' => '',
		'el_data_field2_err' => esc_html__( 'only alphanumeric characters, spaces, hyphens, underscores and [ ] symbols', 'fupi' ),
		'option_arr_id'		=> $option_arr_id,
		'label_for' 		=> $option_arr_id . '[track_affiliate]',
		'under field' 		=> esc_html__( 'If you don\'t provide a name, a full link address will be sent to GTM.', 'fupi' ),
	),
	array(
		'type'	 			=> 'toggle',
		'label' 			=> esc_html__( 'Track clicks on email and tel. links', 'fupi' ),
		'field_id' 			=> 'track_email_tel',
		'class'				=> 'fupi_standard',
		'option_arr_id'		=> $option_arr_id,
	),
	array(
		'type'	 			=> 'text',
		'label' 			=> esc_html__( 'Track clicks on file download links', 'fupi' ),
		'field_id' 			=> 'track_file_downl',
		'class'				=> 'fupi_standard',
		'placeholder'		=> 'e.g. pdf, doc, docx, xls, xlsx, txt',
		'option_arr_id'		=> $option_arr_id,
		'label_for' 		=> $option_arr_id . '[track_file_downl]',
		'under field'		=> esc_html__( 'Enter coma separated list of file formats (extensions) you want to track', 'fupi'),
	),
	array(
		'type'	 			=> 'repeater',
		'label' 			=> esc_html__( 'Track clicks on page elements', 'fupi' ),
		'field_id' 			=> 'track_elems',
		'class'				=> 'fupi_repeater_section',
		'el_data_field1_txt' => esc_html__( 'CSS selector e.g. #sth img', 'fupi' ),
		'el_data_field1_req' => esc_html__( 'this field is required', 'fupi' ),
		'el_data_field1_err' => esc_html__( 'incorrect selector', 'fupi' ),
		'el_data_field2_txt' => esc_html__( 'element name (required)', 'fupi' ),
		'el_data_field2_req' => esc_html__( 'this field is required', 'fupi' ),
		'el_data_field2_err' => esc_html__( 'only alphanumeric characters, spaces, hyphens, underscores and [ ] symbols', 'fupi' ),
		'option_arr_id'		=> $option_arr_id,
		'label_for' 		=> $option_arr_id . '[track_elems]',
	),
);

foreach( $fields as $field ){
	add_settings_field( $field['field_id'], $field['label'], array( $this, 'fupi_field_html' ), $page, $section_id, $field );
}

// FORM TRACKING

$section_id = 'fupi_gtm_forms';
add_settings_section( $section_id, esc_html__( 'Track forms', 'fupi' ), array( $this, 'fupi_sections_descriptions'), $page );

$fields = array(
	array(
		'type'	 			=> 'repeater',
		'label' 			=> esc_html__( 'Track form submissions', 'fupi' ),
		'field_id' 			=> 'track_forms',
		'class'				=> 'fupi_repeater_section',
		'el_data_field1_txt' => esc_html__( 'CSS selector e.g. #form_id', 'fupi' ),
		'el_data_field1_req' => esc_html__( 'this field is required', 'fupi' ),
		'el_data_field1_err' => esc_html__( 'incorrect selector', 'fupi' ),
		'el_data_field2_txt' => esc_html__( 'form name', 'fupi' ),
		'el_data_field2_req' => esc_html__( 'this field is required', 'fupi' ),
		'el_data_field2_err' => esc_html__( 'only alphanumeric characters, spaces, hyphens, underscores and [ ] symbols', 'fupi' ),
		'option_arr_id'		=> $option_arr_id,
		'label_for' 		=> $option_arr_id . '[track_forms]',
		'under field'		=> esc_html__( 'Test this feature after enabling. There are many methods of submitting forms. If this method of tracking fails on your form, track clicks on form submit button instead.', 'fupi'),
	),
);

foreach( $fields as $field ){
	add_settings_field( $field['field_id'], $field['label'], array( $this, 'fupi_field_html' ), $page, $section_id, $field );
}

// VIEWS & SCROLLS TRACKING

$section_id = 'fupi_gtm_scrolls';
add_settings_section( $section_id, esc_html__( 'Track scrolls & visibility', 'fupi' ), array( $this, 'fupi_sections_descriptions'), $page );

$fields = array(
	array(
		'type'	 			=> 'toggle',
		'label' 			=> esc_html__( 'Track when the window visibility state changes', 'fupi' ),
		'field_id' 			=> 'track_focus',
		'option_arr_id'		=> $option_arr_id,
		'under field'		=> esc_html__( 'This will send an event every time the window gets "focus" or "blur" visibility state, e.g. when visitor starts viewing a webpage (focus) or moves to a different browser tab (blur).', 'fupi' ),
	),
	array(
		'type'	 			=> 'repeater',
		'label' 			=> esc_html__( 'Track when these elements become visible', 'fupi' ),
		'field_id' 			=> 'track_views',
		'class'				=> 'fupi_repeater_section',
		'el_data_field1_txt' => esc_html__( 'CSS selector e.g. .side img', 'fupi' ),
		'el_data_field1_req' => esc_html__( 'this field is required', 'fupi' ),
		'el_data_field1_err' => esc_html__( 'incorrect selector', 'fupi' ),
		'el_data_field2_txt' => esc_html__( 'element name', 'fupi' ),
		'el_data_field2_req' => esc_html__( 'this field is required', 'fupi' ),
		'el_data_field2_err' => esc_html__( 'only alphanumeric characters, spaces, hyphens, underscores and [ ] symbols', 'fupi' ),
		'option_arr_id'		=> $option_arr_id,
		'label_for' 		=> $option_arr_id . '[track_views]',
		'under field'		=> esc_html__( 'Use this function to track when elements are scrolled into the visible area of the page OR when they become visible (like popups). Elements are counted as "visible" when they are 200px inside the viewport. Each view is counted once per page view.', 'fupi'),
	),
	array(
		'type'	 			=> 'text',
		'label' 			=> esc_html__( 'Send an event when visitors scroll to:', 'fupi' ),
		'under field'		=> esc_html__( 'e.g. 25, 50, 75.', 'fupi'),
		'after field'		=> esc_html__( '% of page height', 'fupi'),
		'field_id' 			=> 'track_scroll',
		'class'				=> 'fupi_standard',
		'el_class'			=> 'fupi_condition',
		'el_data_target'	=> 'fupi_track_scroll_intr',
		'option_arr_id'		=> $option_arr_id,
		'label_for' 		=> $option_arr_id . '[track_scroll]',
		'under field'		=> esc_html__( 'Separate multiple values with comas. Do not use "%" symbol.', 'fupi'),
	),
	array(
		'type'	 			=> 'number',
		'label' 			=> esc_html__( 'Send an event if visitor scrolled more than:', 'fupi' ),
		'default'			=> '200',
		'after field'		=> esc_html__( 'pixels.', 'fupi'),
		'field_id' 			=> 'track_scroll_min',
		'class'				=> 'fupi_sub fupi_track_scroll_intr fupi_disabled',
		'option_arr_id'		=> $option_arr_id,
		'label_for' 		=> $option_arr_id . '[track_scroll_min]',
		'under field'		=> esc_html__( 'Prevents firing events on short pages. Default is 200px.', 'fupi'),
	),
	array(
		'type'	 			=> 'number',
		'label' 			=> esc_html__( 'Do not send an event if scroll happened in the first:', 'fupi' ),
		'default'			=> '5',
		'after field'		=> esc_html__( 'seconds', 'fupi' ),
		'field_id' 			=> 'track_scroll_time',
		'class'				=> 'fupi_sub fupi_track_scroll_intr fupi_disabled',
		'option_arr_id'		=> $option_arr_id,
		'label_for' 		=> $option_arr_id . '[track_scroll_time]',
		'under field'		=> esc_html__( 'Prevents tracking "exploratory" scrolls. Default is 5 seconds. The event will fire if the visitor is still below the specified scroll depth after the time has passed.', 'fupi'),
	),
);

foreach( $fields as $field ){
	add_settings_field( $field['field_id'], $field['label'], array( $this, 'fupi_field_html' ), $page, $section_id, $field );
}

// URL TRACKING

$section_id = 'fupi_gtm_urls';
add_settings_section( $section_id, esc_html__( 'Track URLs', 'fupi' ), array( $this, 'fupi_sections_descriptions'), $page );

$fields = array(
	array(
		'type'	 			=> 'toggle',
		'label' 			=> esc_html__( 'Track AJAX-triggered URL changes', 'fupi' ),
		'field_id' 			=> 'track_dynamic_urls',
		'option_arr_id'		=> $option_arr_id,
		'tooltip'			=> esc_html__( 'Track dynamic pages where content is added with no page refresh', 'fupi'),
	),
	array(
		'type'	 			=> 'toggle',
		'label' 			=> esc_html__( 'Track clicks on same-page anchors', 'fupi' ),
		'field_id' 			=> 'track_anchor_clicks',
		'option_arr_id'		=> $option_arr_id,
		'tooltip'			=> esc_html__( 'Enable this to track clicks in links that lead to different sections on the same page.', 'fupi'),
	),
);

foreach( $fields as $field ){
	add_settings_field( $field['field_id'], $field['label'], array( $this, 'fupi_field_html' ), $page, $section_id, $field );
}

// USER DATA TRACKING

$section_id = 'fupi_gtm_users';
add_settings_section( $section_id, esc_html__( 'Track user info', 'fupi' ), array( $this, 'fupi_sections_descriptions'), $page );

$fields = array(
	array(
		'type'	 			=> 'toggle',
		'label' 			=> esc_html__( 'Track time of user engagement', 'fupi' ),
		'field_id' 			=> 'track_engagement',
		'class'				=> 'fupi_standard',
		'option_arr_id'		=> $option_arr_id,
		'tooltip'			=> esc_html__( 'Sends an event with the time the user was engaged with the page\'s content. The event is sent just before the user closes the page. Attention! The method of calculating user engagement time is not supported by Internet Explorer browsers!', 'fupi'),
		'after field'		=> sprintf( esc_html__( 'Learn %1$show engagement time is calculated%2$s.', 'fupi'), '<a href="https://fullpictureplugin.com/?p=888&utm_source=useradmin&utm_medium=settings&utm_campaign=settings_link">', '</a>' ),
	),
	array(
		'type'	 			=> 'toggle',
		'label' 			=> esc_html__( 'Track visitor\'s login status and user role (if logged in)', 'fupi' ),
		'field_id' 			=> 'user_role',
		'class'				=> 'fupi_standard',
		'option_arr_id'		=> $option_arr_id,
	),
	array(
		'type'	 			=> 'toggle',
		'label' 			=> esc_html__( 'Track user ID of logged-in users', 'fupi' ),
		'field_id' 			=> 'user_id',
		'class'				=> 'fupi_standard',
		'option_arr_id'		=> $option_arr_id,
		'tooltip'			=> esc_html__( 'User ID is sent in an encoded format', 'fupi'),
	),
	array(
		'type'	 			=> 'toggle',
		'label' 			=> esc_html__( 'Track visitor\'s browser language', 'fupi' ),
		'field_id' 			=> 'browser_lang',
		'class'				=> 'fupi_standard',
		'option_arr_id'		=> $option_arr_id,
	),
	array(
		'type'	 			=> 'toggle',
		'label' 			=> esc_html__( 'Track if visitors are using ad-blocking browser extensions', 'fupi' ),
		'field_id' 			=> 'detect_adblock',
		'class'				=> 'fupi_standard',
		'option_arr_id'		=> $option_arr_id,
		'label_for' 		=> $option_arr_id . '[detect_adblock]',
	)
);

foreach( $fields as $field ){
	add_settings_field( $field['field_id'], $field['label'], array( $this, 'fupi_field_html' ), $page, $section_id, $field );
}

// WP DATA

$section_id = 'fupi_gtm_wpdata';
add_settings_section( $section_id, esc_html__( 'Track WP data', 'fupi' ), array( $this, 'fupi_sections_descriptions'), $page );

$fields = array(
	array(
		'type'	 			=> 'toggle',
		'label' 			=> esc_html__( 'Track page language', 'fupi' ),
		'field_id' 			=> 'page_lang',
		'class'				=> 'fupi_standard',
		'option_arr_id'		=> $option_arr_id,
	),
	array(
		'type'	 			=> 'toggle',
		'label' 			=> esc_html__( 'Track page titles', 'fupi' ),
		'field_id' 			=> 'page_title',
		'class'				=> 'fupi_standard',
		'option_arr_id'		=> $option_arr_id,
		'tooltip'			=> esc_html__( 'Sends WP default titles and meta titles (SEO titles).', 'fupi'),
	),
	array(
		'type'	 			=> 'toggle',
		'label' 			=> esc_html__( 'Track page type', 'fupi' ),
		'field_id' 			=> 'page_type',
		'class'				=> 'fupi_standard',
		'option_arr_id'		=> $option_arr_id,
	),
	array(
		'type'	 			=> 'toggle',
		'label' 			=> esc_html__( 'Track page IDs', 'fupi' ),
		'field_id' 			=> 'page_id',
		'class'				=> 'fupi_standard',
		'option_arr_id'		=> $option_arr_id,
	),
	array(
		'type'	 			=> 'toggle',
		'label' 			=> esc_html__( 'Track page numbers and archive page numbers', 'fupi' ),
		'field_id' 			=> 'page_num',
		'class'				=> 'fupi_standard',
		'option_arr_id'		=> $option_arr_id,
	),
	array(
		'type'	 			=> 'toggle',
		'label' 			=> esc_html__( 'Track author\'s display names', 'fupi' ),
		'field_id' 			=> 'author',
		'class'				=> 'fupi_standard',
		'option_arr_id'		=> $option_arr_id,
		'tooltip'			=> esc_html__( 'Display names are names that are displayed to visitors. Enable this option only if they are not real names (it is against Goolge\'s policy)', 'fupi'),
	),
	array(
		'type'	 			=> 'toggle',
		'label' 			=> esc_html__( 'Track authors IDs', 'fupi' ),
		'field_id' 			=> 'author_id',
		'class'				=> 'fupi_standard',
		'option_arr_id'		=> $option_arr_id,
	),
	array(
		'type'	 			=> 'toggle',
		'label' 			=> esc_html__( 'Track post and page publish dates', 'fupi' ),
		'field_id' 			=> 'post_date',
		'class'				=> 'fupi_standard',
		'option_arr_id'		=> $option_arr_id,
	),
	array(
		'type'	 			=> 'toggle',
		'label' 			=> esc_html__( 'Track post terms', 'fupi' ),
		'field_id' 			=> 'terms',
		'class'				=> 'fupi_standard',
		'option_arr_id'		=> $option_arr_id,
		'tooltip'			=> esc_html__( 'Terms are e.g. tags and categories of posts and pages.', 'fupi'),
	),
	array(
		'type'	 			=> 'toggle',
		'label' 			=> esc_html__( 'Track search terms', 'fupi' ),
		'field_id' 			=> 'search_terms',
		'class'				=> 'fupi_standard',
		'option_arr_id'		=> $option_arr_id,
	),
	array(
		'type'	 			=> 'toggle',
		'label' 			=> esc_html__( 'Track the number of search results', 'fupi' ),
		'field_id' 			=> 'search_results',
		'class'				=> 'fupi_standard',
		'option_arr_id'		=> $option_arr_id,
	),
);

foreach( $fields as $field ){
	add_settings_field( $field['field_id'], $field['label'], array( $this, 'fupi_field_html' ), $page, $section_id, $field );
}

// E-COMMERCE

$section_id = 'fupi_gtm_ecomm';
add_settings_section( $section_id, esc_html__( 'E-Commerce tracking (PRO)', 'fupi' ), array( $this, 'fupi_sections_descriptions'), $page );


?>
