<?php

$page = 'fupi_hotj';

// Integration setup

$section_id = 'fupi_hotj_basic';
add_settings_section( $section_id, esc_html__( 'Basic settings', 'fupi' ), array( $this, 'fupi_sections_descriptions'), $page );

if ( $this->cook_enabled ){
	$cook_opt = array(
		'type'	 			=> 'toggle',
		'label' 			=> esc_html__( 'Load Hotjar without waiting for cookie consent', 'fupi' ),
		'field_id' 			=> 'disreg_cookies',
		'option_arr_id'		=> $option_arr_id,
		'under field'		=> esc_html__( 'This option has an effect only if you chose to load tracking tools after user gives their consent to cookies. Enable this option to verify hotjar and/or allow for complete session recordings and heatmaps. By leaving it enabled you make your website not compliant with Cookie Law.', 'fupi'),
	);
} else {
	$cook_opt = array(
		'type'				=> 'hidden',
		'field_id' 			=> 'disreg_cookies', // database version
		'label'				=> '', // not used but required in foreach below
	);
}

$fields = array(
	array(
		'type'	 			=> 'text',
		'label' 			=> esc_html__( 'Site ID', 'fupi' ),
		'field_id' 			=> 'id',
		'class'				=> 'fupi_required fupi_easy',
		'option_arr_id'		=> $option_arr_id,
		'label_for' 		=> $option_arr_id . '[id]',
	'under field'		=> esc_html__( 'Log in to Hotjar and choose the correct account. Site ID will be in that page\'s URL', 'fupi') . ' ( https://insights.hotjar.com/sites/**[SITE_ID]**/ )',
	),
	$cook_opt,
);

foreach( $fields as $field ){
	add_settings_field( $field['field_id'], $field['label'], array( $this, 'fupi_field_html' ), $page, $section_id, $field );
}

// SESSION TAGGING

$section_id = 'fupi_hotj_tags';
add_settings_section( $section_id, esc_html__( 'Tagging*', 'fupi' ), array( $this, 'fupi_sections_descriptions'), $page );

$fields = array(
	array(
		'type'	 			=> 'toggle',
		'label' 			=> esc_html__( 'Track clicks on outbound links', 'fupi' ),
		'field_id' 			=> 'tag_outbound',
		'class'				=> 'fupi_standard',
		'option_arr_id'		=> $option_arr_id,
		'under field'		=> esc_html__( 'Tags clicks on all links that lead to other domains. Affiliate links leading to other sites are also treated as outbound. Attention! This WILL greatly increase the number of tags associated with your site!', 'fupi'),
	),
	array(
		'type'	 			=> 'repeater',
		'label' 			=> esc_html__( 'Track clicks on affiliate links', 'fupi' ),
		'field_id' 			=> 'tag_affiliate',
		'class'				=> 'fupi_repeater_section',
		'el_data_field1_txt' => esc_html__( 'url part, e.g. /go/', 'fupi' ),
		'el_data_field1_type' => 'url_part',
		'el_data_field1_req' => esc_html__( 'this field is required', 'fupi' ),
		'el_data_field1_err' => '',
		'el_data_field2_txt' => esc_html__( 'tag name (optional)', 'fupi' ),
		'el_data_field2_req' => '',
		'el_data_field2_err' => esc_html__( 'only alphanumeric characters, spaces, hyphens, underscores and [ ] symbols', 'fupi' ),
		'option_arr_id'		=> $option_arr_id,
		'label_for' 		=> $option_arr_id . '[tag_affiliate]',
		'under field'		=> esc_html__( 'Attention! Depending on the number of affiliate links you are using, this may greatly increase the number of tags associated with your site!', 'fupi'),
	),
	array(
		'type'	 			=> 'toggle',
		'label' 			=> esc_html__( 'Track clicks on email and tel. links', 'fupi' ),
		'field_id' 			=> 'tag_email_tel',
		'class'				=> 'fupi_standard',
		'option_arr_id'		=> $option_arr_id,
	),
	array(
		'type'	 			=> 'text',
		'label' 			=> esc_html__( 'Track clicks on file download links', 'fupi' ),
		'field_id' 			=> 'tag_file_downl',
		'class'				=> 'fupi_standard',
		'placeholder'		=> 'pdf, doc, docx, xls, xlsx, txt',
		'option_arr_id'		=> $option_arr_id,
		'label_for' 		=> $option_arr_id . '[tag_file_downl]',
		'under field'		=> esc_html__( 'Enter coma separated list of file formats you want to track', 'fupi'),
	),
	array(
		'type'	 			=> 'toggle',
		'label' 			=> esc_html__( 'Track anchor clicks (links leading to elements on the same page)', 'fupi' ),
		'field_id' 			=> 'tag_anchor_clicks',
		'class'				=> 'fupi_standard',
		'option_arr_id'		=> $option_arr_id,
		'under field'		=> esc_html__( 'Enable this to tag clicks in links that lead to different sections on the same page. Attention! If you use many anchors this may greatly increase the number of tags associated with your site!', 'fupi'),
	),
	array(
		'type'	 			=> 'repeater',
		'label' 			=> esc_html__( 'Track clicks on page elements', 'fupi' ),
		'field_id' 			=> 'tag_elems',
		'class'				=> 'fupi_repeater_section',
		'el_data_field1_txt' => esc_html__( 'CSS selector e.g. #sth img', 'fupi' ),
		'el_data_field1_req' => esc_html__( 'this field is required', 'fupi' ),
		'el_data_field1_err' => esc_html__( 'incorrect selector', 'fupi' ),
		'el_data_field2_txt' => esc_html__( 'element name (required)', 'fupi' ),
		'el_data_field2_req' => esc_html__( 'this field is required', 'fupi' ),
		'el_data_field2_err' => esc_html__( 'only alphanumeric characters, spaces, hyphens, underscores and [ ] symbols', 'fupi' ),
		'option_arr_id'		=> $option_arr_id,
		'label_for' 		=> $option_arr_id . '[tag_elems]',
	),
	array(
		'type'	 			=> 'repeater',
		'label' 			=> esc_html__( 'Track form submissions', 'fupi' ),
		'field_id' 			=> 'tag_forms',
		'class'				=> 'fupi_repeater_section',
		'el_data_field1_txt' => esc_html__( 'CSS selector e.g. #form_id', 'fupi' ),
		'el_data_field1_req' => esc_html__( 'this field is required', 'fupi' ),
		'el_data_field1_err' => esc_html__( 'incorrect selector', 'fupi' ),
		'el_data_field2_txt' => esc_html__( 'form name (required)', 'fupi' ),
		'el_data_field2_req' => esc_html__( 'this field is required', 'fupi' ),
		'el_data_field2_err' => esc_html__( 'only alphanumeric characters, spaces, hyphens, underscores and [ ] symbols', 'fupi' ),
		'option_arr_id'		=> $option_arr_id,
		'label_for' 		=> $option_arr_id . '[tag_forms]',
		'under field'		=> esc_html__( 'Test this feature after enabling. There are many methods of submitting forms. If this method of tracking fails on your form, track clicks on form submit button instead.', 'fupi'),
	),
	array(
		'type'	 			=> 'repeater',
		'label' 			=> esc_html__( 'Track when these elements become visible', 'fupi' ),
		'field_id' 			=> 'tag_views',
		'class'				=> 'fupi_repeater_section',
		'el_data_field1_txt' => esc_html__( 'CSS selector e.g. .side img', 'fupi' ),
		'el_data_field1_req' => esc_html__( 'this field is required', 'fupi' ),
		'el_data_field1_err' => esc_html__( 'incorrect selector', 'fupi' ),
		'el_data_field2_txt' => esc_html__( 'element name (required)', 'fupi' ),
		'el_data_field2_req' => esc_html__( 'this field is required', 'fupi' ),
		'el_data_field2_err' => esc_html__( 'only alphanumeric characters, spaces, hyphens, underscores and [ ] symbols', 'fupi' ),
		'option_arr_id'		=> $option_arr_id,
		'label_for' 		=> $option_arr_id . '[tag_views]',
		'under field'		=> esc_html__( 'Use this function to track when elements are scrolled into the visible area of the page OR when they become visible (like popups). Elements are counted as "visible" when they are 200px inside the viewport. Each view is counted once per page view.', 'fupi'),
	),
	array(
		'type'	 			=> 'toggle',
		'label' 			=> esc_html__( 'Track visitor\'s login status and user role (if logged in)', 'fupi' ),
		'field_id' 			=> 'tag_user_role',
		'class'				=> 'fupi_standard',
		'option_arr_id'		=> $option_arr_id,
	),
	array(
		'type'	 			=> 'toggle',
		'label' 			=> esc_html__( 'Track page type', 'fupi' ),
		'field_id' 			=> 'tag_pagetype',
		'class'				=> 'fupi_standard',
		'option_arr_id'		=> $option_arr_id,
	),
	array(
		'type'	 			=> 'toggle',
		'label' 			=> esc_html__( 'Track page author', 'fupi' ),
		'field_id' 			=> 'tag_pageauthor',
		'class'				=> 'fupi_standard',
		'option_arr_id'		=> $option_arr_id,
	),
	array(
		'type'	 			=> 'toggle',
		'label' 			=> esc_html__( 'Track UTM campaign parameters', 'fupi' ),
		'field_id' 			=> 'tag_utm',
		'option_arr_id'		=> $option_arr_id,
		'under field'		=> esc_html__( 'Attention! If you conduct many advertising campaigns this may greatly increase the number of tags associated with your site!', 'fupi'),
	),
	array(
		'type'	 			=> 'toggle',
		'label' 			=> esc_html__( 'Track JavaScript errors', 'fupi' ),
		'field_id' 			=> 'tag_js_err',
		'option_arr_id'		=> $option_arr_id,
		'under field'		=> esc_html__( 'When enabled, Full Picture will inform Hotjar when JavaScript errors occur on your site. Attention! Use this only sparrigly and for very short time. This WILL greatly increase the number of tags associated with your site!', 'fupi'),
	),
);

foreach( $fields as $field ){
	add_settings_field( $field['field_id'], $field['label'], array( $this, 'fupi_field_html' ), $page, $section_id, $field );
}

// E-COMMERCE

$section_id = 'fupi_hotj_ecomm';
add_settings_section( $section_id, esc_html__( 'E-Commerce Tagging (PRO)', 'fupi' ), array( $this, 'fupi_sections_descriptions'), $page );

$fields = array(
	array(
		'type'	 			=> 'multi checkbox',
		'label' 			=> esc_html__( 'Tag purchases with:', 'fupi' ),
		'field_id' 			=> 'tag_purchases',
		'option_arr_id'		=> $option_arr_id,
		'options' 			=> array(
			'id'				=> esc_html__( 'Order ID', 'fupi' ),
			'p_id'				=> esc_html__( 'Product IDs (one tag for each product)', 'fupi' ),
			'p_name'			=> esc_html__( 'Product names (on tag for each product)', 'fupi' ),
		),
		'under field'		=> esc_html__('Attention! Each selected option will trigger a single or multiple tags. This may greatly increase the number of tags associated with your site! Do not select any option to disable. ', 'fupi'),
	),
	array(
		'type'	 			=> 'multi checkbox',
		'label' 			=> esc_html__( 'Tag checkouts with:', 'fupi' ),
		'field_id' 			=> 'tag_checkouts',
		'option_arr_id'		=> $option_arr_id,
		'class'				=> $disable_for_free_class,
		'options' 			=> array(
			'p_id'				=> esc_html__( 'Product IDs (one tag for each product)', 'fupi' ),
			'p_name'			=> esc_html__( 'Product names (on tag for each product)', 'fupi' ),
		),
		'under field'		=> esc_html__('Attention! Each selected option will trigger a single or multiple tags. This may greatly increase the number of tags associated with your site! Do not select any option to disable. ', 'fupi'),
	),
	array(
		'type'	 			=> 'multi checkbox',
		'label' 			=> esc_html__( 'Tag "add to cart" events with:', 'fupi' ),
		'field_id' 			=> 'tag_addtocart',
		'option_arr_id'		=> $option_arr_id,
		'class'				=> $disable_for_free_class,
		'options' 			=> array(
			'p_id'				=> esc_html__( 'Product IDs (one tag for each product)', 'fupi' ),
			'p_name'			=> esc_html__( 'Product names (on tag for each product)', 'fupi' ),
		),
		'under field'		=> esc_html__('Attention! Each selected option will trigger a single or multiple tags. This may greatly increase the number of tags associated with your site! Do not select any option to disable. ', 'fupi'),
	),
	array(
		'type'	 			=> 'multi checkbox',
		'label' 			=> esc_html__( 'Tag "remove from cart" events with:', 'fupi' ),
		'field_id' 			=> 'tag_removefromcart',
		'option_arr_id'		=> $option_arr_id,
		'class'				=> $disable_for_free_class,
		'options' 			=> array(
			'p_id'				=> esc_html__( 'Product IDs (one tag for each product)', 'fupi' ),
			'p_name'			=> esc_html__( 'Product names (on tag for each product)', 'fupi' ),
		),
		'under field'		=> esc_html__('Attention! Each selected option will trigger a single or multiple tags. This may greatly increase the number of tags associated with your site! Do not select any option to disable. ', 'fupi'),
	),
	array(
		'type'	 			=> 'multi checkbox',
		'label' 			=> esc_html__( 'Tag "add to wishlist" events with:', 'fupi' ),
		'field_id' 			=> 'tag_addtowishlst',
		'option_arr_id'		=> $option_arr_id,
		'class'				=> $disable_for_free_class,
		'options' 			=> array(
			'role'				=> esc_html__( 'Product IDs (one tag for each product)', 'fupi' ),
			'role'				=> esc_html__( 'Product names (on tag for each product)', 'fupi' ),
		),
		'under field'		=> esc_html__('Attention! Each selected option will trigger a single or multiple tags. This may greatly increase the number of tags associated with your site! Do not select any option to disable. ', 'fupi'),
	),
);

foreach( $fields as $field ){
	add_settings_field( $field['field_id'], $field['label'], array( $this, 'fupi_field_html' ), $page, $section_id, $field );
}


// USER IDENTIFICATION

$section_id = 'fupi_hotj_users';
add_settings_section( $section_id, esc_html__( 'User tracking', 'fupi' ), array( $this, 'fupi_sections_descriptions'), $page );

$fields = array(
	array(
		'type'	 			=> 'toggle',
		'label' 			=> esc_html__( 'Enable user identification', 'fupi' ),
		'field_id' 			=> 'identif_users',
		'option_arr_id'		=> $option_arr_id,
		'el_class'			=> 'fupi_condition',
		'el_data_target'	=> 'fupi_hotj_identif',
		'tooltip'			=> esc_html__( 'Attributes can be associated only to identified users. Identification is done with User ID (for logged-in users) or Hotjar ID (for other visitors)', 'fupi'),
	),
	array(
		'type'	 			=> 'multi checkbox',
		'label' 			=> esc_html__( 'Associate users with attributes', 'fupi' ),
		'field_id' 			=> 'user_attr',
		'option_arr_id'		=> $option_arr_id,
		'class'				=> 'fupi_sub fupi_hotj_identif fupi_disabled',
		'options' 			=> array(
			'role'				=> esc_html__( 'User role', 'fupi' ),
			'email'				=> esc_html__( 'User email', 'fupi' ),
		),
		'under field'		=> esc_html__('Please enable global setting "Allow tracking emails of logged-in users" in "Main settings" > "Privacy & security settings" tab for email tracking feature to work.', 'fupi'),
	),
);

foreach( $fields as $field ){
	add_settings_field( $field['field_id'], $field['label'], array( $this, 'fupi_field_html' ), $page, $section_id, $field );
}

?>
