<?php

$page = 'fupi_sbee';

// BASIC

$section_id = 'fupi_sbee_basic';
add_settings_section( $section_id, esc_html__( 'Basic settings', 'fupi' ), array( $this, 'fupi_sections_descriptions'), $page );

if ( $this->cook_enabled ){
	$cook_opt = array(
		'type'	 			=> 'toggle',
		'label' 			=> esc_html__( 'Load Splitbee without waiting for cookie consent', 'fupi' ),
		'field_id' 			=> 'disreg_cookies',
		'option_arr_id'		=> $option_arr_id,
		'under field'		=> esc_html__( 'This option has an effect only if you did not enable the above option and chose to load cookies after user consent. By leaving it enabled you make your website not compliant with Cookie Law.', 'fupi'),
	);
} else {
	$cook_opt = array(
		'type'				=> 'hidden',
		'field_id' 			=> 'disreg_cookies', // database version
		'label'				=> '', // not used but required in foreach below
	);
}

$fields = array(
	array(
		'type'	 			=> 'toggle',
		'label' 			=> esc_html__( 'Use Splitbee in "no cookies" mode (beta)', 'fupi' ),
		'field_id' 			=> 'no_cookies',
		'class'				=> 'fupi_easy',
		'option_arr_id'		=> $option_arr_id,
		'under field'		=> esc_html__( 'When enabled, Splitbee will not require cookie consent. Be aware that this affects the accuracy of your data. Visitors are no longer tracked across multiple days.', 'fupi'),
	),
	$cook_opt,
);

foreach( $fields as $field ){
	add_settings_field( $field['field_id'], $field['label'], array( $this, 'fupi_field_html' ), $page, $section_id, $field );
}

// AB TESTS

$section_id = 'fupi_sbee_tests';
add_settings_section( $section_id, esc_html__( 'Content Experiments*', 'fupi' ), array( $this, 'fupi_sections_descriptions'), $page );

$fields = array(
	array(
		'type'	 			=> 'toggle',
		'label' 			=> esc_html__( 'Enable content experiments', 'fupi' ),
		'field_id' 			=> 'enable_ab_tests',
		'class'				=> 'fupi_standard',
		'el_class'			=> 'fupi_condition',
		'el_data_target'	=> 'fupi_sub_ab_tests',
		'option_arr_id'		=> $option_arr_id,
	),
	array(
		'type'	 			=> 'toggle',
		'label' 			=> esc_html__( 'Prevent flash of original content', 'fupi' ),
		'field_id' 			=> 'no_async',
		'class'				=> 'fupi_sub fupi_sub_ab_tests fupi_disabled fupi_standard',
		'option_arr_id'		=> $option_arr_id,
		'after field'		=> esc_html__( '(recommended)', 'fupi' ),
		'under field'		=> esc_html__( 'If you enable this option Splitbee script will be set as "blocking". It will pause rendering of the page until the experiment loads. Without it original page content may show up for a brief moment before it is replaced by the tested variant.', 'fupi'),
	),
);

foreach( $fields as $field ){
	add_settings_field( $field['field_id'], $field['label'], array( $this, 'fupi_field_html' ), $page, $section_id, $field );
}

// EVENT TRACKING

$section_id 		= 'fupi_sbee_events';
add_settings_section( $section_id, esc_html__( 'Events tracking', 'fupi' ), array( $this, 'fupi_sections_descriptions'), $page );

$fields = array(
	array(
		'type'	 			=> 'repeater',
		'label' 			=> esc_html__( 'Track clicks on affiliate links', 'fupi' ),
		'field_id' 			=> 'track_affiliate',
		'class'				=> 'fupi_repeater_section',
		'el_data_field1_txt' => esc_html__( 'url part, e.g. /go/', 'fupi' ),
		'el_data_field1_type' => 'url_part',
		'el_data_field1_req' => esc_html__( 'this field is required', 'fupi' ),
		'el_data_field1_err' => '',
		'el_data_field2_txt' => esc_html__( 'name (optional)', 'fupi' ),
		'el_data_field2_req' => '',
		'el_data_field2_err' => esc_html__( 'only alphanumeric characters, spaces, hyphens, underscores and [ ] symbols', 'fupi' ),
		'option_arr_id'		=> $option_arr_id,
		'label_for' 		=> $option_arr_id . '[track_affiliate]',
	),
	array(
		'type'	 			=> 'text',
		'label' 			=> esc_html__( 'Track clicks on file download links', 'fupi' ),
		'field_id' 			=> 'track_file_downl',
		'class'				=> 'fupi_standard',
		'placeholder'		=> 'pdf, doc, docx, xls, xlsx, txt',
		'option_arr_id'		=> $option_arr_id,
		'label_for' 		=> $option_arr_id . '[track_file_downl]',
		'under field'		=> sprintf(esc_html__( 'Enter coma separated list of file formats you want to track.', 'fupi'), '<a href="#">', '</a>' ),
	),
	array(
		'type'	 			=> 'toggle',
		'label' 			=> esc_html__( 'Track clicks on email and tel. links', 'fupi' ),
		'field_id' 			=> 'track_email_tel',
		'class'				=> 'fupi_standard',
		'option_arr_id'		=> $option_arr_id,
	),
	array(
		'type'	 			=> 'toggle',
		'label' 			=> esc_html__( 'Track clicks on cookie notice buttons', 'fupi' ),
		'field_id' 			=> 'track_c_notice_btns',
		'class'				=> 'fupi_standard',
		'option_arr_id'		=> $option_arr_id,
	),
	array(
		'type'	 			=> 'repeater',
		'label' 			=> esc_html__( 'Track clicks on page elements', 'fupi' ),
		'field_id' 			=> 'track_elems',
		'class'				=> 'fupi_repeater_section',
		'el_data_field1_txt' => esc_html__( 'CSS selector e.g. #sth img', 'fupi' ),
		'el_data_field1_req' => esc_html__( 'this field is required', 'fupi' ),
		'el_data_field1_err' => esc_html__( 'incorrect selector', 'fupi' ),
		'el_data_field2_txt' => esc_html__( 'element name (required)', 'fupi' ),
		'el_data_field2_req' => esc_html__( 'this field is required', 'fupi' ),
		'el_data_field2_err' => esc_html__( 'only alphanumeric characters, spaces, hyphens, underscores and [ ] symbols', 'fupi' ),
		'option_arr_id'		=> $option_arr_id,
		'label_for' 		=> $option_arr_id . '[track_elems]',
	),
	array(
		'type'	 			=> 'repeater',
		'label' 			=> esc_html__( 'Track form submissions', 'fupi' ),
		'field_id' 			=> 'track_forms',
		'class'				=> 'fupi_repeater_section',
		'el_data_field1_txt' => esc_html__( 'CSS selector e.g. #form_id', 'fupi' ),
		'el_data_field1_req' => esc_html__( 'this field is required', 'fupi' ),
		'el_data_field1_err' => esc_html__( 'incorrect selector', 'fupi' ),
		'el_data_field2_txt' => esc_html__( 'form name (required)', 'fupi' ),
		'el_data_field2_req' => esc_html__( 'this field is required', 'fupi' ),
		'el_data_field2_err' => esc_html__( 'only alphanumeric characters, spaces, hyphens, underscores and [ ] symbols', 'fupi' ),
		'option_arr_id'		=> $option_arr_id,
		'label_for' 		=> $option_arr_id . '[track_forms]',
		'under field'		=> esc_html__( 'Attention! Test this feature after enabling. There are many methods of submitting forms. If this method of tracking fails for your form, track "clicks" on "submit" button instead.', 'fupi'),
	),
);

foreach( $fields as $field ){
	add_settings_field( $field['field_id'], $field['label'], array( $this, 'fupi_field_html' ), $page, $section_id, $field );
}

// USER DETAILS

$section_id = 'fupi_sbee_user';
add_settings_section( $section_id, esc_html__( 'User info tracking', 'fupi' ), array( $this, 'fupi_sections_descriptions'), $page );

$fields = array(
	array(
		'type'	 			=> 'toggle',
		'label' 			=> esc_html__( 'Track login status and user role', 'fupi' ),
		'field_id' 			=> 'track_user_role',
		'class'				=> 'fupi_standard',
		'option_arr_id'		=> $option_arr_id,
	),
	array(
		'type'	 			=> 'toggle',
		'label' 			=> esc_html__( 'Track email addresses of logged-in users', 'fupi' ),
		'field_id' 			=> 'track_user_email',
		'class'				=> 'fupi_standard',
		'option_arr_id'		=> $option_arr_id,
		'under field'		=> esc_html__( 'Please enable global setting "Allow tracking emails of logged-in users" in "Main settings" > "Privacy & security settings" tab for this feature to work.', 'fupi' ),
	),
);

foreach( $fields as $field ){
	add_settings_field( $field['field_id'], $field['label'], array( $this, 'fupi_field_html' ), $page, $section_id, $field );
}

// E-COMMERCE

$section_id = 'fupi_sbee_ecomm';
add_settings_section( $section_id, esc_html__( 'E-Commerce tracking (PRO)', 'fupi' ), array( $this, 'fupi_sections_descriptions'), $page );

?>
