<?php

/**
 * Plugin Name:       Full Picture
 * Plugin URI:        https://fullpictureplugin.com/
 * Description:       Integrate your site with 12 tools like Google Analytics, GTM, Microsoft Clarity, Plausible, LInked In. Use 30+ unique features and a GDPR-compliant cookie notice.
 * Version:           2.1.1
 * Requires at least: 5.0
 * Requires PHP:      7.2
 * Author:            Krzysztof Planeta
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       fupi
 * Domain Path:       /languages
 */
// If this file is called directly, abort.
if ( !defined( 'ABSPATH' ) ) {
    exit;
}

if ( function_exists( 'fupi_fs' ) ) {
    fupi_fs()->set_basename( false, __FILE__ );
} else {
    // DO NOT REMOVE THIS IF, IT IS ESSENTIAL FOR THE `function_exists` CALL ABOVE TO PROPERLY WORK.
    
    if ( !function_exists( 'fupi_fs' ) ) {
        // this will be removed in FREE version
        // Create a helper function for easy SDK access.
        function fupi_fs()
        {
            global  $fupi_fs ;
            
            if ( !isset( $fupi_fs ) ) {
                // Include Freemius SDK.
                require_once dirname( __FILE__ ) . '/freemius/start.php';
                $fupi_fs = fs_dynamic_init( array(
                    'id'             => '5405',
                    'slug'           => 'full-picture-analytics-cookie-notice',
                    'premium_slug'   => 'full-picture-analytics-cookie-notice-pro',
                    'type'           => 'plugin',
                    'public_key'     => 'pk_2aee883bf3a3ae5559a119e92c744',
                    'is_premium'     => false,
                    'premium_suffix' => 'PRO',
                    'has_addons'     => false,
                    'has_paid_plans' => true,
                    'anonymous_mode' => !function_exists( 'fupi_premium_test__premium_only' ),
                    'menu'           => array(
                    'slug'       => 'full_picture_tools',
                    'first-path' => 'admin.php?page=full_picture_tools',
                    'contact'    => false,
                    'support'    => false,
                ),
                    'is_live'        => true,
                ) );
            }
            
            return $fupi_fs;
        }
        
        // Init Freemius.
        fupi_fs();
        // Signal that SDK was initiated.
        do_action( 'fupi_fs_loaded' );
    }
    
    $can_use = false;
    define( 'FUPI_VERSION', '2.1.1' );
    define( 'FUPI_URL', plugin_dir_url( __FILE__ ) );
    define( 'FUPI_PATH', __DIR__ );
    // [slug; page title; can be used in current plan; is premium; is standard module (0) OR is cookie notice (1) OR is the tab general settings (2); order]
    // order is important - modules will show up in this order in the side menu and tab menus!
    // first 3 elements will always show up in the order given below because they are hardcoded later
    define( 'FUPI_MODULES', [
        [
        'tools',
        'Modules',
        true,
        false,
        0,
        0
    ],
        [
        'main',
        'Global Settings',
        true,
        false,
        0,
        0
    ],
        [
        'cook',
        'Cookie Notice',
        true,
        false,
        1,
        0
    ],
        [
        'ga41',
        'Google Analytics 4',
        true,
        false,
        0,
        10
    ],
        [
        'ga42',
        'Google Analytics 4 #2',
        $can_use,
        true,
        0,
        20
    ],
        [
        'ga1',
        'Google Analytics UA',
        true,
        false,
        0,
        30
    ],
        [
        'ga2',
        'Google Analytics UA #2',
        $can_use,
        true,
        0,
        40
    ],
        [
        'gtm',
        'Google Tag Manager',
        true,
        false,
        0,
        50
    ],
        [
        'gopt',
        'Google Optimize',
        true,
        false,
        0,
        60
    ],
        [
        'gads',
        'Google Ads',
        $can_use,
        true,
        0,
        70
    ],
        [
        'fbp1',
        'Facebook Pixel',
        true,
        false,
        0,
        80
    ],
        [
        'fbp2',
        'Facebook Pixel #2',
        $can_use,
        true,
        0,
        90
    ],
        [
        'mads',
        'Microsoft Advertising',
        $can_use,
        true,
        0,
        100
    ],
        [
        'clar',
        'Microsoft Clarity',
        true,
        false,
        0,
        110
    ],
        [
        'twit',
        'Twitter Ads',
        $can_use,
        true,
        0,
        120
    ],
        [
        'pin',
        'Pinterest Ads',
        $can_use,
        true,
        0,
        130
    ],
        [
        'hotj',
        'Hotjar',
        true,
        false,
        0,
        140
    ],
        [
        'linkd',
        'Linked In Insight',
        true,
        false,
        0,
        150
    ],
        [
        'pla',
        'Plausible',
        true,
        false,
        0,
        160
    ],
        [
        'sbee',
        'Splitbee',
        true,
        false,
        0,
        170
    ],
        [
        'insp',
        'Inspectlet',
        true,
        false,
        0,
        180
    ],
        [
        'cegg',
        'Crazy Egg',
        true,
        false,
        0,
        190
    ],
        [
        'woo',
        'WooCommerce',
        $can_use,
        true,
        2,
        1000
    ]
    ] );
    // CUSTOM UNINSTALL REASONS
    function fupi_custom_uninstall_reasons( $uninstall_reasons_by_user_type )
    {
        foreach ( $uninstall_reasons_by_user_type as $user_type => $uninstall_reasons ) {
            foreach ( $uninstall_reasons as $key => $uninstall_reason ) {
                switch ( $uninstall_reason['id'] ) {
                    case Freemius::REASON_NO_LONGER_NEEDED:
                    case Freemius::REASON_TEMPORARY_DEACTIVATION:
                    case Freemius::REASON_NEEDED_FOR_A_SHORT_PERIOD:
                    case Freemius::REASON_CANT_PAY_ANYMORE:
                    case Freemius::REASON_DONT_LIKE_TO_SHARE_MY_INFORMATION:
                        unset( $uninstall_reasons_by_user_type[$user_type][$key] );
                        break;
                }
            }
        }
        return $uninstall_reasons_by_user_type;
    }
    
    fupi_fs()->add_filter( 'uninstall_reasons', 'fupi_custom_uninstall_reasons' );
    // Don't show the trial promotional admin notice.
    function fupi_custom_show_admin_notice( $show, $msg )
    {
        if ( 'trial_promotion' == $msg['id'] ) {
            return false;
        }
        return $show;
    }
    
    fupi_fs()->add_filter(
        'show_admin_notice',
        'fupi_custom_show_admin_notice',
        10,
        2
    );
    // ACTIVATE
    function activate_fupi()
    {
        require_once plugin_dir_path( __FILE__ ) . 'includes/class-fupi-activator.php';
        Fupi_Activator::activate();
    }
    
    register_activation_hook( __FILE__, 'activate_fupi' );
    // DEACTIVATE
    function deactivate_fupi()
    {
        require_once plugin_dir_path( __FILE__ ) . 'includes/class-fupi-deactivator.php';
        Fupi_Deactivator::deactivate();
    }
    
    register_deactivation_hook( __FILE__, 'deactivate_fupi' );
    // REMOVE FREEMIUS SUBMENU LINKS
    function fupi_is_submenu_visible( $is_visible, $submenu_id )
    {
        return false;
    }
    
    fupi_fs()->add_filter(
        'is_submenu_visible',
        'fupi_is_submenu_visible',
        10,
        2
    );
    // ADD SETTINGS LINK TO THE ENTRY ON PLUGINS LIST
    function fupi_plugin_settings_link( $links )
    {
        $settings_link = '<a href="admin.php?page=full_picture_tools">Settings</a>';
        array_unshift( $links, $settings_link );
        return $links;
    }
    
    add_filter( 'plugin_action_links_' . plugin_basename( __FILE__ ), 'fupi_plugin_settings_link' );
    /**
     * The core plugin class that is used to define internationalization,
     * admin-specific hooks, and public-facing site hooks.
     */
    require plugin_dir_path( __FILE__ ) . 'includes/class-fupi.php';
    /**
     * Begins execution of the plugin.
     *
     * Since everything within the plugin is registered via hooks,
     * then kicking off the plugin from this point in the file does
     * not affect the page life cycle.
     *
     * @since    1.0.0
     */
    function run_fupi()
    {
        $plugin = new Fupi();
        $plugin->run();
    }
    
    run_fupi();
}
