<?php

class Fupi
{
    protected  $loader ;
    public function get_loader()
    {
        return $this->loader;
    }
    
    protected  $plugin_name ;
    public function get_plugin_name()
    {
        return $this->plugin_name;
    }
    
    protected  $version ;
    public function get_version()
    {
        return $this->version;
    }
    
    public function __construct()
    {
        
        if ( defined( 'FUPI_VERSION' ) ) {
            $this->version = FUPI_VERSION;
        } else {
            $this->version = '1.0.0';
        }
        
        $this->plugin_name = 'full_picture';
        $this->tools = get_option( 'fupi_tools' );
        $this->main = get_option( 'fupi_main' );
        if ( empty($this->tools) ) {
            $this->tools = $this->main;
        }
        $this->woo = get_option( 'fupi_woo' );
        $this->load_dependencies();
        $this->set_locale();
        $this->define_admin_hooks();
        $this->define_public_hooks();
    }
    
    private function load_dependencies()
    {
        // STANDARD FUPI
        require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-fupi-loader.php';
        require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-fupi-i18n.php';
        require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-fupi-notices.php';
        require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/class-fupi-admin.php';
        require_once plugin_dir_path( dirname( __FILE__ ) ) . 'public/class-fupi-public.php';
        $this->loader = new Fupi_Loader();
    }
    
    private function set_locale()
    {
        $plugin_i18n = new Fupi_i18n();
        $this->loader->add_action( 'plugins_loaded', $plugin_i18n, 'fupi_load_plugin_textdomain' );
    }
    
    private function define_admin_hooks()
    {
        $plugin_admin = new Fupi_Admin( $this->get_plugin_name(), $this->get_version() );
        $this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'fupi_enqueue_scripts' );
        $this->loader->add_action( 'admin_menu', $plugin_admin, 'fupi_add_admin_page' );
        $this->loader->add_action( 'admin_menu', $plugin_admin, 'fupi_add_plausible_stats_page' );
        $this->loader->add_action( 'admin_init', $plugin_admin, 'fupi_register_settings' );
        $this->loader->add_action( 'admin_init', $plugin_admin, 'fupi_activation_redirect' );
        $this->loader->add_action( 'admin_init', $plugin_admin, 'fupi_admin_notices' );
        $this->loader->add_action( 'admin_notices', $plugin_admin, 'fupi_admin_notices_non_dismissable' );
        $this->loader->add_action( 'customize_register', $plugin_admin, 'fupi_customize_register' );
        $this->loader->add_action( 'wp_ajax_nopriv_clearcache_ajax', $plugin_admin, 'fupi_clearcache_ajax' );
        $this->loader->add_action( 'wp_ajax_clearcache_ajax', $plugin_admin, 'fupi_clearcache_ajax' );
        $this->loader->add_action( 'customize_preview_init', $plugin_admin, 'fupi_customizer_preview_scripts' );
    }
    
    private function define_public_hooks()
    {
        $plugin_public = new Fupi_Public( $this->get_plugin_name(), $this->get_version() );
        // add "page labels" taxonomy
        if ( !empty($this->main) && isset( $this->main['label_pages'] ) ) {
            $this->loader->add_action( 'init', $plugin_public, 'fupi_page_labels' );
        }
        $this->loader->add_action( 'init', $plugin_public, 'fupi_add_shortcodes' );
        $this->loader->add_action(
            'wp_head',
            $plugin_public,
            'fupi_get_data',
            -1
        );
        // includes all the "Get" scripts
        $this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'fupi_enqueue_public_scripts' );
        $this->loader->add_action( 'wp_footer', $plugin_public, 'fupi_output_in_footer' );
    }
    
    public function run()
    {
        $this->loader->run();
    }

}