"use strict";

(function() {

	'use strict';

	var notice = FP.findID('fupi_cookie_notice'),
		panel = {},
		added_events_to_notice_btns = false;
		panel.welcome = FP.findID('fupi_welcome_panel');
		panel.settings = FP.findID('fupi_settings_panel');

	// INIT ON LOAD

	// if geolocation is disabled OR if it is enabled and the notice should show in current country
	if( typeof fp.notice.show_in_current_country == 'undefined' || fp.notice.show_in_current_country === true ) {
		if ( !fp.notice.use_custom_notice ){
			// show default notice
			show_notice_on_load_or_request();
		} else {
			add_events_to_custom_notice_btns();
		}
	// if geolocation is enabled but location is still unknown
	} else {
		FP.keepChecking( is_location_known, 50, 1000,
			function() { if( fp.notice.show_in_current_country === true ) { show_notice_on_load_or_request() } }, {}
		);
	}

	// FUNCTIONS

	function remove_blur() {
		setTimeout( function(){
			var html_el = document.getElementsByTagName( 'html' )[0];
			if( html_el.classList.contains('fupi_blur') ) {
				html_el.classList.remove('fupi_blur');
				html_el.classList.add('fupi_blur_out');
			}
		}, 300 );
	}
	function is_location_known() {
		return fp.notice.show_in_current_country !== 'checking';
	}

	function show_notice_on_load_or_request() {

		// show notice when there are NO cookie preferences saved...
		if ( ! fp.cookies ) {

			show_notice();

			// slide out cookie settings on click
			show_cookie_settings_on_click();

		} else {
			// slide out cookie settings on click
			show_cookie_settings_on_click(true);
		}
	}

	function show_cookie_settings_on_click(set_switches) {

		set_switches = set_switches || false;

		var custom_settings_class = fp.notice.use_custom_notice && fp.notice.custom_cookies_settings_class ? ', ' + fp.notice.custom_cookies_settings_class : '',
			show_notice_links = FP.findAll('.fupi_show_cookie_notice, .fp_show_cookie_notice' + custom_settings_class);

		if(show_notice_links.length) {
			show_notice_links.forEach(function(link) {
				link.addEventListener('click', function(e) {
					e.preventDefault();
					// e.stopPropagation() @from: 1.8.0
					if(set_switches) set_switches_state();
					show_notice_wrapper();
					panel.settings ? show_panel('settings') : show_panel('welcome');
				});
			});
		}
	}

	function set_switches_state() {
		var switches = FP.findAll(".fupi_switch input");

		if(switches.length > 0) {
			switches.forEach(function(the_switch) {
				if(fp.cookies[the_switch.value]) the_switch.checked = true;
			});
		}
	}

	function add_events_to_custom_notice_btns(){

		var custom_accept_btn = fp.notice.use_custom_notice && fp.notice.custom_agree_cookies_class ? FP.findFirst( fp.notice.custom_agree_cookies_class ) : false,
			custom_decline_btn = fp.notice.use_custom_notice && fp.notice.custom_decline_cookies_class ? FP.findFirst( fp.notice.custom_decline_cookies_class ) : false;

		if( custom_accept_btn ) {
			custom_accept_btn.addEventListener('click', accept_all_cookies_and_fire_custom_event );
		}

		if( custom_decline_btn ){
			custom_decline_btn.addEventListener( 'click', decline_all_cookies )
		}

		show_cookie_settings_on_click();
	}

	function add_events_to_buttons_in_notice() {
		var accept_all_btn = FP.findID('fupi_agree_to_all_cookies_btn'),
			decline_btn = FP.findID('fupi_decline_cookies_btn'),
			cookie_settings_btn = FP.findID('fupi_cookie_settings_btn'),
			accept_chosen_btn = FP.findID('fupi_agree_to_selected_cookies_btn'),
			return_btn = FP.findID('fupi_return_btn'),
			switches = FP.findAll(".fupi_switch");

		if( accept_all_btn ) {
			accept_all_btn.addEventListener('click', function(){
				accept_all_cookies_and_fire_custom_event();
				hide_panel('welcome');
				hide_notice_wrapper();
				remove_blur();
			});
		}

		if( decline_btn ) {
			decline_btn.addEventListener('click', function(){
				decline_all_cookies();
				hide_panel('welcome');
				hide_notice_wrapper();
			});
		}

		if( accept_chosen_btn ) {
			accept_chosen_btn.addEventListener('click', function(){
				accept_chosen_cookies();
				hide_panel('settings');
				hide_notice_wrapper();
			});
		}

		if( cookie_settings_btn ) {
			cookie_settings_btn.addEventListener('click', function() {
				hide_panel('welcome');
				show_panel('settings');
			});
		}

		if( return_btn ) {
			return_btn.addEventListener('click', function() {
				hide_panel('settings');
				show_panel('welcome');
			});
		}

		if( switches ) {
			switches.forEach(function(the_switch) {
				the_switch.addEventListener('click', function(e) {
					toggle_switch(e.target);
				}, false);
			});
		}
	}

	// ACCESSIBLE SWITCH
	// https://developer.mozilla.org/en-US/docs/Web/Accessibility/ARIA/Roles/Switch_role

	function toggle_switch(target) {
		if(target.getAttribute("aria-checked") == "true") {
			target.setAttribute("aria-checked", "false");
		} else {
			target.setAttribute("aria-checked", "true");
		}
	}

	function accept_all_cookies_and_fire_custom_event() {
		var newCookieVal = {
			'stats': true,
			'personalisation': true,
			'marketing': true,
			'disabled': false
		};
		FP.setCookie('fp_cookie', JSON.stringify(newCookieVal), 3650);
		fp.cookies = newCookieVal;
		FP.sendEvt('fp_load_scripts', ['all']);
	}

	function accept_chosen_cookies() {

		var stats_checkbox = FP.findID('fupi_stats_agree'),
			perso_checkbox = FP.findID('fupi_pers_agree'),
			marke_checkbox = FP.findID('fupi_marketing_agree'),
			some_scripts_are_loaded = fp.loaded.length > 1, // the only non-integration script is helpers-footer so we need start from 1
			newCookieVal = {
				'stats': stats_checkbox ? stats_checkbox.checked : false,
				'personalisation': perso_checkbox ? perso_checkbox.checked : false,
				'marketing': marke_checkbox ? marke_checkbox.checked : false,
				'disabled': false
			};

		FP.setCookie('fp_cookie', JSON.stringify(newCookieVal), 3650);
		fp.cookies = newCookieVal;

		if(some_scripts_are_loaded) {
			location.reload();
		} else {
			FP.sendEvt('fp_load_scripts', ['all']);
		}
	}

	function decline_all_cookies() {

		var some_scripts_are_loaded = fp.loaded.length > 1, // the only non-integration script is helpers-footer so we need start from 1
			newCookieVal = {
				'stats': false,
				'personalisation': false,
				'marketing': false,
				'disabled': false
			};

		FP.setCookie('fp_cookie', JSON.stringify(newCookieVal), 3650);
		fp.cookies = newCookieVal;

		if( some_scripts_are_loaded ) location.reload();
	}

	function show_panel(type) {
		if(panel[type]) {
			panel[type].classList.remove('fupi_fadeOutDown');
			panel[type].classList.remove('fupi_hidden');
			panel[type].classList.add('fupi_animated');
			panel[type].classList.add('fupi_fadeInUp');

			if(!added_events_to_notice_btns) {
				add_events_to_buttons_in_notice();
				added_events_to_notice_btns = true;
			}
		}
	}

	function hide_panel(type) {
		panel[type].classList.remove('fupi_fadeInUp');
		panel[type].classList.add('fupi_animated');
		panel[type].classList.add('fupi_fadeOutDown');
	}

	function show_notice_wrapper() {
		notice.classList.remove('fupi_fadeOutDown');
		notice.classList.remove('fupi_hidden');
		notice.classList.add('fupi_fadeInUp');
		notice.classList.add('fupi_animated');
	}

	function hide_notice_wrapper() {
		notice.classList.remove('fupi_fadeInUp');
		notice.classList.add('fupi_fadeOutDown');
	}

	function show_notice() {
		show_notice_wrapper();
		show_panel('welcome');
		show_cookie_settings_on_click();
	}

})();
