(function (window){

	FP.makeName = function ( str, el ) {
		if ( str ) {
			if ( str.indexOf('[name]') != -1  ) {
				var textContent = el.textContent;
				if ( textContent.length > 20 ) {
					textContent.substring(0, 20);
				};
				return str.replace('[name]', textContent);
			} else {
				return str;
			}
		} else {
			return false;
		}
	}

	FP.runAdblockTest = function () {
		var _v = fp.data.vars;
        if ( _v.adblock != 'testing' && _v.adblock != 'tested' ) {
            _v.adblock = 'testing';
            FP.getScript( _v.url + '/public/helpers/ads.js' );
        }
    }

    FP.isAdblockEnabled = function () {
        var _v = fp.data.vars;
        if ( _v.adblock != 'tested' ) {
            var div = FP.findID('ads_kas98j');
            _v.adblock = 'tested';
            _v.adblock_enabled = ! div ? true : false;
            return _v.adblock_enabled;
        } else {
            return _v.adblock_enabled;
        }
    };

	FP.splitTextarea = function (module, address) {

        var temp_a = fp[module][address].split("\n").map(function (line) {
            var trimmed = line.trim();
            return trimmed.length > 0 ? trimmed.split('@') : false;

        });

        fp[module][address] = temp_a.filter( function ( el ) {
            if ( el !== false ) return el;
        });
    };

    FP.isOutboundLink = function (el) {
        return el.href.indexOf(location.host) == -1 && el.href.indexOf('mailto:') != 0 && el.href.indexOf('tel:') != 0 && el.href.indexOf('http') == 0;
    };

    FP.isFileUrl = function (url, file_formats) {
        var last_url_part = url.split('/').pop(),
        	files_arr = file_formats.split(',').map(function (file) {
            	return file.trim();
        	});

		return files_arr.some(function (file) {
            return last_url_part.indexOf( '.' + file.toLowerCase() ) != -1;
        });
    };

	FP.getFilenameOnly = function( url ){

		try {
			var clear_link = url.split('/').pop().split('?')[0];
		} catch (e) {
			console.error(e);
			var clear_link = false;
		}

		return clear_link;
	}

    FP.isContactLink = function (el) {
        return el.href.indexOf('mailto:') == 0 ? [el, 'mail'] : el.href.indexOf('tel:') == 0 ? [el, 'tel'] : false;
    };

	FP.prepareElsForIntersObserver = function (data_a, dataname) { // data_a >> [ [select, name], [select, name], [select, name], ... ]

        var selectors_a = [];
        data_a.forEach(function (arr) {

            // get all the elements that match the selector
            var els_a = FP.findAll(arr[0]);

            if (els_a.length > 0) {
                // check if any el is on page
                // save elements in array
                selectors_a.push(arr[0]);

				if( dataname !== false ){
					// name elements
					els_a.forEach(function (el) {
						el.dataset[dataname] = arr[1] || arr[0];
					});
				}
            }
        });
        return selectors_a; // returns an array of CSS selectors of elements that exist on page
    };

	FP.intersectionObserver = function (observer_name, selectors_s, settings, action, unobserve, passed_val) {
		unobserve = unobserve || false;
		passed_val = passed_val || false;

		var els = FP.findAll(selectors_s),
			opts = settings || {};

		if (!fp.observers) fp.observers = {};

		if (els.length) {
			// If the browser supports IntersectionObserver
			if ('IntersectionObserver' in window) {
				fp.observers[observer_name] = new IntersectionObserver(function (objs, observer) {
					objs.forEach( function (obj) {
						if ( obj.isIntersecting ) {
							if ( unobserve ) { observer.unobserve(obj.target); };
							action.call(this, obj.target, passed_val);
						}
					});
				}, opts);
				els.forEach(function (el) {
					return fp.observers[observer_name].observe(el);
				});
			// if the browser doesn't support IntersectionObserver
			} else {
				if ( fp.data.vars.ie11_observer == 'loading' ) {
					setTimeout( function () { FP.intersectionObserver(observer_name, selectors_s, settings, action, unobserve, passed_val) }, 500 )
				} else {
					fp.data.vars.ie11_observer = 'loading';
					FP.getScript(
						fp.data.vars.url + 'public/helpers/fupi-ie11-intersection-observer.js',
						function(){
							fp.data.vars.ie11_observer = 'loaded';
							FP.intersectionObserver(observer_name, selectors_s, settings, action, unobserve, passed_val);
						}
					);
				}
			}
		}
	};

	// check if the visitor scrolled more than minimum
    FP.testScroll = function (scroll_height, scroll_percent, scroll_points, min_scroll) {
        var return_a = [false, false],
            max = scroll_points.length; // find the highest scroll point

        if (scroll_height >= min_scroll && max > 0) {
            for (var i = 0; i < max; i++) {
                if (scroll_percent > scroll_points[i]) {
                    return_a = [true, scroll_points[i]];
                }
            }
        }

        // clear points array up to and including the found point
        if (return_a[1]) {
            var clear_up_to_this_index = scroll_points.indexOf(return_a[1]);
            scroll_points.splice(0, clear_up_to_this_index + 1);
        }

        return return_a;
    };

	FP.trackClicks = function (e, actions, is_middle_click) {

        // prevent multi clicks
        var now = Date.now();

        if ( ! FP.v.lastClick || now - FP.v.lastClick > fp.data.vars.dblclck_time ) {

            FP.v.lastClick = now;

            var target = e.target,
				link = FP.findClosestLinkEl(target),
				requests_new_tab = false;

            if ( link && link.href.length > 1 ) {

                if ( link.target == '_blank' ) requests_new_tab = true;

                // TRACK OUTBOUND LINKS
                if ( actions.outbound && FP.isOutboundLink(link) ) {
                    actions.outbound.forEach(function (data_a) {
                        var action = data_a[0],
                            passed_val = data_a[1] || false;
                        action(e, link, passed_val);
                    });
                }

                // TRACK ANCHOR LINKS
                if ( actions.anchors && FP.isAnchorLinkToCurrentPage(link) ) {
                    actions.anchors.forEach(function (data_a) {
                        var action = data_a[0],
                            passed_val = data_a[1] || false;
                        action(e, link, passed_val);
                    });

					if ( fp.data.vars.reset_timer_on_anchor ) FP.v.timeOnPage = 0; // reset timer after each anchor click
                }

                // TRACK AFFILIATE LINKS
                if (actions.affiliate) {
                    actions.affiliate.forEach(function (data_a) {

                        var action = data_a[0],
                        	lines_a = data_a[1],
                        	passed_val = data_a[2] || false,
                        	max = lines_a.length,
                        	i = 0;

                        for (; i < max; i++) {
                            var link_data_a = lines_a[i],
                                url_part = link_data_a[0],
                                is_aff_link = link.href.indexOf(url_part) != -1;

                            if (is_aff_link) {
								var name = FP.makeName( link_data_a[1], link ) || link.href;
                                i = max + 1;
                                action(e, link, name, passed_val);
                            }
                        }
                    });
                }

                // TRACK CONTACT LINKS
                if (actions.email_tel) {
                    var return_val = FP.isContactLink(link);

                    if (return_val !== false) {
                        actions.email_tel.forEach(function (data_a) {
                            var action = data_a[0],
                            passed_val = data_a[1] || false;
                            action(e, return_val, passed_val);
                        });
                    }
                }

                // TRACK FILE DOWNLOAD LINK CLICKS
                if (actions.downl) {
                    actions.downl.forEach(function (data_a) {
                        var action = data_a[0],
                            file_formats = data_a[1],
                            passed_val = data_a[2] || false;

                        if ( FP.isFileUrl(link.href, file_formats) ) {
							var filename = FP.getFilenameOnly( link.href );
							if ( filename) action(e, filename, passed_val);
                        }
                    });
                }
            }

            // TRACK ANY ELEM CLICKS
            // left click works always
            // middle click works only with links

            if ( actions.elem && ( !is_middle_click || is_middle_click && !!link ) ) {

                actions.elem.forEach( function (data_a) {

                    var action = data_a[0],
                        searched_els_a = data_a[1],
                        passed_val = data_a[2] || false,
                        max = searched_els_a.length,
                        i = 0;

                    for (; i < max; i++) {

                        var selector = searched_els_a[i][0],
							searched_el = false;

						if ( target.matches(selector) ) {
							searched_el = target;
						} else {
							var closest_el = target.closest(selector);
							if ( closest_el ) searched_el = closest_el;
						}

                        if (searched_el) {

							var name = FP.makeName( searched_els_a[i][1], searched_el ) || selector;

                            i = max + 1;
                            action(e, searched_el, name, passed_val);
                        }
                    }
                });
            }
        }
    };

	//
	// FIRE EVENTS
	//

    // Async events
    // see https://www.youtube.com/watch?v=8aGhZQkoFbQ (from 18:50)
    // function asyncForEach(arr, cb){
    //     arr.forEach( function (){
    //         setTimeout(cb, 0);
    //     })
    // }

	// ON FORM SUBMIT
	// uses 1 second delay to:
	// - prevent sending events on forms that were submitted within the first 1 sec from page load
	// - make sure that all ajax loaded forms get loaded

	var wait_for_forms = fp.data.vars.formsubm_trackdelay ? fp.data.vars.formsubm_trackdelay * 1000 : 1000;

	setTimeout( function(){

		FP.findAll('form').forEach( function (form) {

			form.addEventListener('submit', function (e) {

				if (fp.on_form_submit) {
					fp.on_form_submit.forEach(function (data_a) {

						data_a[1].forEach(function (form_data) {
							if ( e.target.matches(form_data[0]) ) {
								var action = data_a[0],
									passed_val = data_a[2],
									label = form_data[1] || false;
								action(e, label, passed_val);
							}
						});
					});
				}
			});
		} )
	}, wait_for_forms );

	// ON SCROLL ( + USER ACTVITY TRACKER )
    // event throttled to fire every 50 ms

    function on_scroll() {
        FP.startActivityTimer();

        if (fp.on_scroll) {
            var page_height = document.body.clientHeight,
                scroll_height = FP.scrollTop(),
                scroll_percent = 100 / (page_height - FP.v.viewport.height) * scroll_height; // update live variable

            if (scroll_percent > FP.v.maxScroll) FP.v.maxScroll = scroll_percent;

            fp.on_scroll.forEach(function (data_a, i) {
                var action = data_a[0],
                    scroll_points = data_a[1],
                    min_scroll = data_a[2],
                    passed_val = data_a[3] || false,
                    test_results = FP.testScroll(scroll_height, scroll_percent, scroll_points, min_scroll),
                    test_passed = test_results[0],
                    return_val = test_results[1];
                if (test_passed) action(return_val, passed_val);
            });
        }
    }

    document.addEventListener( 'scroll', FP.throttle( on_scroll, 50, {trailing: true } ) );

	// ON LEFT CLICK
	document.addEventListener( 'click', function (e) {
		if (fp.on_click) {
			FP.trackClicks(e, fp.on_click, false);
		}
	});

	// ON MIDDLE CLICK
	document.addEventListener( 'mouseup', function (e) {
		if (fp.on_middle_click && e.button == 1) {
			FP.trackClicks(e, fp.on_middle_click, true);
		}
	});

	// ON DYNAMIC URL CHANGES
	window.addEventListener( 'popstate', function (e) {
		if (fp.on_url_state && e.state != null) {
			fp.on_url_state.forEach(function (data_a) {
				var action = data_a[0],
					passed_val = data_a[1];
				action(e, passed_val);
			});
		}
	});

	// ON UNLOAD (CLOSING THE PAGE)
    window.addEventListener('beforeunload', function (e) {

		if (fp.on_close) {

			fp.on_close.forEach(function (data_a) {
                var action = data_a[0],
                	passed_val = data_a[1] || false;
                action(passed_val);
            });

			if ( fp.data.vars.debug ) console.log('resetting time on page timer');
			FP.v.timeOnPage = 0; // reset timer if the engagement was sent without page leave (e.g. after clicking a contact, email link or an anchor)
        }
    });

	//!

	fp.loaded.push( 'helpers-footer' );

})(window);
