(function (FP) {

    'use strict';

    var _this = this;

    var d = document,
    w = window;
    FP.v = {};
    FP.v.viewport = {};
    FP.v.maxScroll = 0;
    FP.v.lastActivity = 0;
    FP.v.timeOnPage = 0;
    FP.f = {};

    FP.extend = function (source, properties) {
        var property;
        for (property in properties) {
            if (properties.hasOwnProperty(property)) {
                source[property] = properties[property];
            }
        }
        return source;
    };

    // GET VIEWPORT DIMENSIONS

    FP.updateViewportDimensions = function () {
        var e = d.documentElement,
        g = d.getElementsByTagName('body')[0],
        x = w.innerWidth || e.clientWidth || g.clientWidth,
        y = w.innerHeight || e.clientHeight || g.clientHeight;
        FP.v.viewport = {
            width: x,
            height: y
        };
    };

    // fires function every X ms with an option to fire them ADDITIONALLY on start ("leading") and after events ("trailing")
    FP.throttle = function (func, wait, options) {
        var context, args, result;
        var timeout = null;
        var previous = 0;
        if (!options) options = {};

        var later = function later() {
            previous = options.leading === false ? 0 : Date.now();
            timeout = null;
            result = func.apply(context, args);
            if (!timeout) context = args = null;
        };

        return function () {
            var now = Date.now();
            if (!previous && options.leading === false) previous = now;
            var remaining = wait - (now - previous);
            context = this;
            args = arguments;

            if (remaining <= 0 || remaining > wait) {
                if (timeout) {
                    clearTimeout(timeout);
                    timeout = null;
                }

                previous = now;
                result = func.apply(context, args);
                if (!timeout) context = args = null;
            } else if (!timeout && options.trailing !== false) {
                timeout = setTimeout(later, remaining);
            }

            return result;
        };
    };

    FP.scrollTop = function () {
        var pos = w.pageYOffset || d.documentElement.scrollTop;
        return pos;
    };

    FP.docHeight = function () {
        return Math.max(d.documentElement.clientHeight, d.body.scrollHeight, d.documentElement.scrollHeight, d.body.offsetHeight, d.documentElement.offsetHeight);
    };

    FP.isObjectEmpty = function (obj) {
        return obj.constructor === Object && Object.keys(obj).length === 0;
    };

    FP.isNumeric = function (n) {
        return !isNaN(parseFloat(n)) && isFinite(n);
    };

    FP.startActivityTimer = function () {
        FP.v.lastActivity = FP.v.timeOnPage;

        if (!FP.v.activityTimerRunning) {
            FP.v.activityTimerRunning = true;
            FP.v.activityTimer = setInterval(function () {
                FP.v.timeOnPage++;
                if (FP.v.timeOnPage - FP.v.lastActivity >= 15) FP.stopActivityTimer(); // stop timer after 15 secs from last activity
            }, 1000);
        }
    };

    FP.stopActivityTimer = function () {
        if (FP.v.activityTimerRunning) {
            FP.v.activityTimerRunning = false;
            clearInterval(FP.v.activityTimer);
        }
    };

    FP.encode = function (string) {
         return window.btoa(string).split('=').join('')
    }

    FP.registerAction = function (evt, cat, action) {

        // make sure that event is an array
        var evt_a = Array.isArray(evt) ? evt : [evt];

        evt_a.forEach(function (ev) {
            if (!fp[ev]) fp[ev] = [];

            if (cat) {
                fp[ev][cat] = fp[ev][cat] || [];
                fp[ev][cat].push(action);
            } else {
                fp[ev].push(action);
            }
        });
    };

    // CONVERT NODE LIST TO ARRAY

    FP.nl2Arr = function (nl) {
        if (nl) {
            return [].slice.call(nl);
        } else {
            return false;
        }
    };

    FP.remove = function (el) {
        if (el) el.parentNode.removeChild(el);
    };

    FP.keepChecking = function (rule, every, until, cb, args) {
        args ? args : false;
        var timer = 0,
        stopChecking = setInterval(function () {
            if (rule()) {
                cb.call(this, args);
                clearInterval(stopChecking);
            }

            timer += every;

            if (timer == until) {
                clearInterval(stopChecking);
            }
        }, every);
    };

    FP.userDate = function () {
        var jsDate = new Date();
        return jsDate.getFullYear() + ('0' + (jsDate.getMonth() + 1)).slice(-2) + ('0' + jsDate.getDate()).slice(-2);
    };

    FP.findAll = function (e, c) {
        if ( !e ) return false;
        c = c || document;
        return FP.nl2Arr(c.querySelectorAll(e));
    };

    FP.findFirst = function (e, c) {
        if ( !e ) return false;
        c = c || document;
        return c.querySelector(e);
    };

    FP.findID = function (e, c) {
        if ( !e ) return false;
        c = c || document;
        return c.getElementById(e);
    };

    FP.sendEvt = function (evt_name, details_a) {

        var details = details_a ? { 'detail' : details_a } : {};

        if ( typeof window.CustomEvent === "function" ) {
            var fp_event = new CustomEvent( evt_name, details );
            document.dispatchEvent(fp_event);
        // for IE
        } else {
            var params = { bubbles: false, cancelable: false, detail: details },
    		    evt = document.createEvent( 'CustomEvent' );
    		evt.initCustomEvent( event, params.bubbles, params.cancelable, params.detail );
        }
    };

    FP.findClosestLinkEl = function (el) {
        if ( el.href ) {
            return el;
        } else {
            var closest_link = el.closest('a');
            return closest_link && closest_link.href ? closest_link : false; // make sure that <a> has an "href"
        }
    };

    // checks if the link is an anchor to an existing element on the same page
	FP.isAnchorLinkToCurrentPage = function (link) {
        return FP.findFirst( new URL( link.href ).hash );
    };

    FP.isLinkToCurrentPage = function (link) {

         let target_url_obj = new URL( link.href ),
            target_url = target_url_obj.origin + target_url_obj.pathname,
            current_url = location.origin + location.pathname;

         return target_url == current_url ? true : false;
    }

    FP.isAllowedToLoad = function (module_id, permissions_a, required_a, nr) {

        // module id in fp.XX / required cookie permission / setting name with required data (like in fp.ga.setting_name)
        var allow_loading = true,
            id = nr ? module_id + nr : module_id;

        // STOP if the tab is not in focus
        if (document.hidden) allow_loading = false;

        // STOP if script already loaded
        if (allow_loading) {
            if (fp.loaded.indexOf(id) != -1) allow_loading = false;
        }

        // STOP if the required data is missing
        if (allow_loading && required_a.length > 0) {
            required_a.forEach(function (setting_name) {
                if (!fp[id] || fp[id] && !fp[id][setting_name]) allow_loading = false;
            });
        }

        // STOP on first visit...
        if (allow_loading && !fp.cookies) {
            // if we are not dealing with 1st integration of a type...
            if ( ! nr || nr == 1 ) {
                // ...and if the script requires any cookie permissions...
                if (permissions_a.length > 0) {
                    // ...and is NOT forced to load on pageload...
                    if (!fp[id] || fp[id] && !fp[id].disreg_cookies) {
                        // ...and is to load after visitor's consent...
                        if (fp.notice.enable_scripts_after == 'consent') {
                            // ...and geolocation is disabled
                            if ( typeof fp.notice.show_in_current_country == 'undefined' ) { // please note the "typeof"
                                allow_loading = false;
                            // ...and geolocation is enabled...
                            } else {
                                // ...and the notice is to show for visitors in current location or we don't know the location yet
                                // (if we don't know the location, the script will not load. However the moment we learn the location then the cookie notice script will decide whether to show the notice and send an event to load scripts)
                                if (fp.notice.show_in_current_country === true || fp.notice.show_in_current_country == 'checking') {
                                    allow_loading = false;
                                }
                            }
                        }
                    }
                }
            }
        }

        // STOP on consecutive visit if scripts are disabled with URL parameter
        if (allow_loading && fp.cookies && fp.cookies.disabled) allow_loading = false;

        // STOP on consecutive visit if required permissions are not given
        if (allow_loading && fp.cookies && permissions_a.length > 0) {
            if (fp.cookies && !permissions_a.every(function (permission) {
                return fp.cookies[permission];
            })) allow_loading = false;
            // copy of the old script that kept checking "disregarding cookies" condition
            // if (!fp[module_id] || fp[module_id] && !fp[module_id].disreg_cookies) {
            //     if (fp.cookies && !permissions_a.every(function (permission) {
            //         return fp.cookies[permission];
            //     })) allow_loading = false;
            // }
        }

        return allow_loading;
    };

    //!

    // ON TAB FOCUS
    // Do not move to footer helpers
    // this script needs to stop activity timer when a page that is being loaded loses focus

    document.addEventListener('visibilitychange', function () {

        // FIRE TAGS WHEN THE WINDOW TAB GETS FOCUS
        if (!document.hidden) {
            FP.sendEvt( 'fp_load_scripts', ['all'] );
        }

        if (fp.on_tabfocus) {
            if (!document.hidden) {
                fp.on_tabfocus.forEach(function (data_a) {
                    return data_a[0](data_a[2]);
                });

                FP.startActivityTimer();

            } else {
                fp.on_tabfocus.forEach(function (data_a) {
                    return data_a[1](data_a[2]);
                });

                FP.stopActivityTimer();
            }
        }
    }, false);

    // Show an icon indicating that the current user is no longer tracked

	if ( fp.cookies.disabled ) {
		document.addEventListener('DOMContentLoaded', function() {
			document.body.insertAdjacentHTML('afterbegin', '<div id=\'fupi_disabled\' title="Tracking disabled"><svg style="width: 20px;" focusable="false" data-prefix="fas" data-icon="eye-slash" class="svg-inline--fa fa-eye-slash fa-w-20" role="img" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 640 512"><path fill="currentColor" d="M320 400c-75.85 0-137.25-58.71-142.9-133.11L72.2 185.82c-13.79 17.3-26.48 35.59-36.72 55.59a32.35 32.35 0 0 0 0 29.19C89.71 376.41 197.07 448 320 448c26.91 0 52.87-4 77.89-10.46L346 397.39a144.13 144.13 0 0 1-26 2.61zm313.82 58.1l-110.55-85.44a331.25 331.25 0 0 0 81.25-102.07 32.35 32.35 0 0 0 0-29.19C550.29 135.59 442.93 64 320 64a308.15 308.15 0 0 0-147.32 37.7L45.46 3.37A16 16 0 0 0 23 6.18L3.37 31.45A16 16 0 0 0 6.18 53.9l588.36 454.73a16 16 0 0 0 22.46-2.81l19.64-25.27a16 16 0 0 0-2.82-22.45zm-183.72-142l-39.3-30.38A94.75 94.75 0 0 0 416 256a94.76 94.76 0 0 0-121.31-92.21A47.65 47.65 0 0 1 304 192a46.64 46.64 0 0 1-1.54 10l-73.61-56.89A142.31 142.31 0 0 1 320 112a143.92 143.92 0 0 1 144 144c0 21.63-5.29 41.79-13.9 60.11z"></path></svg></div><style>#fupi_disabled{position: fixed; left: 0; bottom: 0; color: #fff; background-color: rgba(0,0,0,.2); padding: 10px 5px; z-index: 10000;cursor: pointer;}#fupi_disabled:hover{background-color: rgba(0,0,0,.8);}</style>');

			var disabled_ico = FP.findID('fupi_disabled');

			disabled_ico.addEventListener('click', function (e) {
                FP.deleteCookie('fp_cookie');
                fp.cookies = false;
                document.location = location.origin;
            })
		});
	}

    // ON MOUSE MOVE FOR USER ACTVITY TRACKER
    document.addEventListener( 'mousemove', FP.throttle( FP.startActivityTimer, 500 ) ); // This starts the user's activity timer

    if ( ! document.hidden) { FP.startActivityTimer(); }; // This starts activity timer with pageload if the page is in focus

    // UPDATE VIEWPORT DIMENSIONS
    // used for scroll tracking
    FP.updateViewportDimensions();
    window.addEventListener( 'resize', FP.throttle( FP.updateViewportDimensions, 100, { trailing: true } ) );

})(FP);
