<?php

$hidden_taxonomies = [];
$label_as_page_types = false;

if ( ! empty( $this->main['hidden_taxonomies'] ) ) {
	if ( is_array( $this->main['hidden_taxonomies'] ) ) {
		$hidden_taxonomies = $this->main['hidden_taxonomies'];
	} else {
		$hidden_taxonomies = array_map( 'trim', explode( ',', $this->main['hidden_taxonomies'] ) );
	};
}

if ( ! empty( $this->main['label_pages'] ) && ! empty( $this->main['label_as_page_types'] ) ) {
	$label_as_page_types = true;
	array_push( $hidden_taxonomies, 'fupi_page_labels' );
}

$data['wp'] = [];

//
// LOGIN STATUS AND USER ROLE
//

if( is_user_logged_in() ) {

	$user = wp_get_current_user();

	// get email
	if ( ! empty( $this->main['allow_tracking_user_emails'] ) ) {
		$data['wp']['user_email'] = $user->user_email;
	}

	// get email
	if ( ! empty( $this->main['allow_tracking_usernames'] ) ) {
		$data['wp']['username'] = $user->display_name;
	}

	// get user id
	$userID = $user->ID;
	$data['wp']['user_logged_in'] = true;
	$data['wp']['user_id'] = $userID !== 0 ? $userID : false;

	// get user role
	$roles = ( array ) $user->roles;
	$data['wp']['user_role'] = $roles[0];

// if user is not logged in
} else {

	// set role as visitor
	$data['wp']['user_role'] = 'Visitor';
	$data['wp']['user_logged_in'] = false;
}

//
// PAGE DATA
//

if ( is_home() ) { // ! returns true for all subpages of post list

	$data['wp']['page_type'] = 'Posts Home';
	$data['wp']['page_title'] = get_the_title( get_option('page_for_posts', true) );

} else if ( is_singular() ) {

	global $post;

	$post_type = get_post_type();
	$post_type_obj = get_post_type_object( $post_type );

	if ( ! empty( $post_type_obj->labels->singular_name ) ) {
		$data['wp']['page_type'] = $post_type_obj->labels->singular_name;
	} else {
		if ( ! empty( $post_type_obj->label ) ){
			$data['wp']['page_type'] = $post_type_obj->label;
		} else {
			$data['wp']['page_type'] = $post_type;
		}
	};

	$data['wp']['page_title'] = $post->post_title;
	$data['wp']['page_id'] = $post->ID;
	$data['wp']['published'] = $post->post_date;
	$data['wp']['author_name'] = get_the_author_meta('display_name', (int) $post->post_author );

	if ( ! empty( $this->main['hide_author_id'] ) ) {
		$data['wp']['author_id'] = (int) $post->post_author;
	}

	$taxonomies = get_object_taxonomies( $post );

	if ( is_array($taxonomies) && count($taxonomies) > 0 ){

		$terms_tmp = [];

		foreach ( $taxonomies as $tax_slug ) {

			// skip page label if it is to be used as a page type
			if ( $label_as_page_types && $tax_slug == 'fupi_page_labels' ) continue;

			// make sure not to include taxonomies that the user chose in the settings
			if ( ! in_array( $tax_slug, $hidden_taxonomies ) ) {

				$terms = get_the_terms( $post, $tax_slug );
				if ( $terms ) {
					foreach ($terms as $term) {

						$term_data = [
							'name' => $term->name,
							'slug' => $term->slug,
							'parent' => $term->parent,
							'taxonomy' => $term->taxonomy,
						];
						array_push($terms_tmp, $term_data);
					}
				}
			}
		}

		if ( count( $terms_tmp ) > 0 ) $data['wp']['terms'] = $terms_tmp;
	}

	if ( is_single() ) {

		if ( is_singular('post') && is_sticky() ) $data['wp']['sticky'] = true;

	} else if ( is_page() ) {

		if ( is_front_page() ) {
			$data['wp']['page_type'] = 'Front Page';
		} else {
			if ( $label_as_page_types )  {

				$terms = get_the_terms( $post, 'fupi_page_labels' );

				if ( $terms ) {
					$data['wp']['page_type'] = $terms[0] ? $terms[0]->name : 'Page';
				}
			}
		}
		if ( $post->post_parent ) { $data['wp']['subpage'] = true; }

	}

	// NOT USEFUL & NOT USED
	// if ( is_page_template() ) {
	// 	$data['wp']['template'] = get_post_meta( $post->ID, '_wp_page_template', true );
	// }

	if ( is_single() || is_page() ) {

		$paged = get_query_var( 'page' ) ? get_query_var( 'page' ) : false;
		// returns result only on 2+ page
		if ( $paged ) { $data['wp']['page_number'] = $paged; }
	}

} else if ( is_archive() ) { // ! returns false on "home" page

	if ( is_category() ) {

		$data['wp']['page_type'] = 'Category';
		$data['wp']['page_title'] = single_term_title('', false);

	} else if ( is_tag() ) {

		$data['wp']['page_type'] = 'Tag';
		$data['wp']['page_title'] = single_term_title('', false);

	} else if ( is_tax() ) { // true for terms of a custom taxonomy

		$data['wp']['page_type'] = 'Custom Taxonomy';

		// get taxonomy name and term title on non archive
		$term = get_queried_object();

		if ( $term ) {

			// page type
			$tax_slug = $term->taxonomy;
			if ( !empty( $tax_slug ) ) {
				$tax = get_taxonomy($tax_slug);
				$data['wp']['page_type'] = ! empty( $tax->labels->singular_name ) ? $tax->labels->singular_name : 'Custom Taxonomy';
			}

			// term name
			$term_name = $term->name;
			if ( !empty( $term_name ) ) {
				$data['wp']['page_title'] = $term_name;
			}
		}

	} else if ( is_author() ) {

		$data['wp']['page_type'] = 'Author Archive';

		$term = get_queried_object();
		if ( $term ) {
			$data['wp']['author'] = $term->data->display_name;

			if ( ! empty( $this->main['hide_author_id'] ) ) {
				$data['wp']['author_id'] = $term->data->id;
			}
		}

	} else if ( is_date() ) {

		$data['wp']['page_type'] = 'Date Archive';

		if ( is_year() ) {
			$data['wp']['page_type'] = 'Year Archive';
		} else if ( is_month() ) {
			$data['wp']['page_type'] = 'Month Archive';
		} else if ( is_day() ) {
			$data['wp']['page_type'] = 'Day Archive';
		} else if ( is_time() ) {
			$data['wp']['page_type'] = 'Time Archive';
		}

	} else { // check if it is a CPT archive

		$data['wp']['page_type'] = 'Archive';
		$term = get_queried_object();

		if ( $term ) {
			$term_name = $term->label;
			if ( ! empty( $term_name ) ) {
				$data['wp']['page_title'] = $term_name;
				$data['wp']['page_type'] = $term_name . ' Archive';
			}
		}
	}

} else if ( is_search() ) {

	$data['wp']['page_type'] = 'Search';

	$search_query = get_search_query();

	if ( $search_query ) {
		$data['wp']['search_query'] = $search_query;
	}

	global $wp_query;
	$data['wp']['search_results'] = $wp_query->found_posts;
	$data['wp']['page_title'] = 'Search results';

}

//
// PAGED ARCHIVES
//

if ( ( is_home() || is_archive() || is_search() ) && is_paged() ) { // returns true on archive pages and home (page 2+)

	$archive_page = get_query_var( 'paged' ) ? get_query_var( 'paged' ) : false;

	if ( $archive_page !== false ) {
		$data['wp']['page_number'] = $archive_page;
	}
}

if ( is_404() ) {
	$data['wp']['page_type'] = '404';
	$data['wp']['page_title'] = '404';
}

?>
